<?php
/**
 *
 *
 *
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */
class Aeres
{
	private $liste = array();
	private $listeCategorie = array();
	private $listeIdFluxUtilise = array();
	private $listeIdItemUtilise = array();
	private $listeIdCategorieUtilise = array();
	private $fichier = "";
	
	public function getListe(){return $this->liste;}
	public function setListe($liste){$this->liste = $liste;}
	
	public function getListeCategorie(){return $this->listeCategorie;}
	public function setListeCategorie($listeCategorie){$this->listeCategorie = $listeCategorie;}
	
	public function getListeIdFluxUtilise(){return $this->listeIdFluxUtilise;}
	public function setListeIdFluxUtilise($listeIdFluxUtilise){$this->listeIdFluxUtilise = $listeIdFluxUtilise;}
	
	public function getListeIdItemUtilise(){return $this->listeIdItemUtilise;}
	public function setListeIdItemUtilise($listeIdItemUtilise){$this->listeIdItemUtilise = $listeIdItemUtilise;}
	
	public function getListeIdCategorieUtilise(){return $this->listeIdCategorieUtilise;}
	public function setListeIdCategorieUtilise($listeIdCategorieUtilise){$this->listeIdCategorieUtilise = $listeIdCategorieUtilise;}
	
	public function getFichier(){return $this->fichier;}
	public function setFichier($fichier){$this->fichier = $fichier;}


	public function __construct()
	{
		chargerCategorie();
	}
	
	
	/**
	 * fonction qui charge le fichier des catégorie
	 */
	public function chargerCategorie()
	{
		$liste = array();
		if(file_exists(NOM_FICHIER_CATEGORIE))
		{
			$xmlLocal = new DOMDocument();
			if(@$xmlLocal->load(NOM_FICHIER_CATEGORIE))
			{
				foreach($xmlLocal->getElementsByTagName('categorie') as $xmlCat)
				{
					$cat = new RssCategorie();
					$cat->setId($xmlCat->getElementsByTagName('id')->item(0)->nodeValue);
					$cat->setPosition($xmlCat->getElementsByTagName('position')->item(0)->nodeValue);
					$cat->setTitre($xmlCat->getElementsByTagName('titre')->item(0)->nodeValue);
					$liste[] = $cat;

					//on va remplir le tableau "arrayIdCategorie" pour pouvoir connaitre facilement l'id suivant intelligent
					$this->listeIdCategorieUtilise['id' . $cat->getId()] = $cat->getId();
				}
			}
			usort($liste, "triCatParPosition");
			$this->setListeCategorie($liste);
		}
		else
		{
			return "fichier catégorie introuvable";	//FIXME à externaliser
		}
	}



	/**
	 * fonction qui va charger la liste des flux en scannant tous les fichiers xml
	 * @return array( int=> array( int=> Rss ) )
	 */
	public function chargerListeFlux($force = false)
	{
		//si on a déjà charger $GLOBALS["listeFluxRss"], on ne rescanne pas sauf cas de force majeur
		if (count($liste) == 0 || $force)
		{
			verifChemin(CHEMIN_FLUX);

			//dans le repertoire de sauvegarde des flux, on va parcourir tous les fichiers pour charger les flux
			$listeCat = array();
			$liste = scandir(CHEMIN_FLUX);
			//si on a des fichiers xml, on va les charger (le 2 correspond à . et ..)
			if(count($liste) > 2)
			{
				foreach($liste as $fichier)
				{
					//on ne se préocupe que des fichiers xml
					if(pathinfo($fichier, PATHINFO_EXTENSION) == "xml")
					{
						$rss = new Rss();
						$rss->chargerFichier(CHEMIN_FLUX . $fichier);
						//on vérifie qu'on a bien pû charger le fichier
						if($rss->getUrlFlux() != "")
						{
							$listeCat[$rss->getIdCa()][] = $rss;

							//on repère les id déjà utilisés pour pouvoir facilement récupérer l'id suivant
							$this->listeIdFluxUtilise['id' . $rss->getId()] = $rss->getId();
						}
						else
						{
							$GLOBALS['msg'] .= $GLOBALS["langue"]->get("FICHIER_NON_CHARGER", $fichier) . "<br>";
						}
					}
				}

				//on va construire un tableau contenant les id libres pour les items
				arsort($GLOBALS["arrayIdItem"]);

				//je ne sais pas si c'est la bonne solution, mais array_shift est la seul méthode que j'ai trouver pour récupérer le 1er élément
				//$tab[0] ne marche pas car j'ai des clés non numérique (pourtant je pensais que ça marchait quand même)
				//Du coup, comme je dépile le 1er élément, il ne faut pas que je le passe dans la boucle car il sera considé comme libre alors qu'il ne l'est forcement pas.
				$max = array_shift($GLOBALS["arrayIdItem"]);

				for ($cpt = 1; $cpt < $max; $cpt++)
				{
					if(!isset($GLOBALS["arrayIdItem"]["id$cpt"]))
					{
						$GLOBALS["arrayIdItemLibre"]["id$cpt"] = $cpt;
					}
				}

				//on ajoute le 1er id supérieur au max qui sera lui toujours libre
				$max++;
				$GLOBALS["arrayIdItemLibre"]["id$max"] = $max;

			}
			//si on en a pas, cela signifie que répertoire vient d'être créé. On va donc créer le fichier .htaccess qui interdit l'acces aux fichiers flux
			else
			{
				verifHtaccess(CHEMIN_FLUX);
			}

			//on va trier les flux par position
			foreach($listeCat as &$listeFlux)
			{
				usort($listeFlux, "triFluxParPosition");
			}
			$this->liste = $listeCat;
		}

		return $this->liste;
	}

	
	/**
	 * fonction qui retourne le premier id non utilisé pour la table $table.
	 *  Lorsque l'on utilise cette fonction, l'id est automatiquement marqué comme utilisé.
	 * @return int
	 */
	public function getIdFluxSuivant()
	{
		$id = 1; //id suivant potentiel. Si je le trouve dans le tableau, j'essaye le suivant
		$trouver = false;
		//j'essaie tous les id à partir de 1 et je teste s'il est dans la liste. S'il n'y est pas, ça sera la valeur de l'id suivant
		while(!$trouver && $id <= count($this->listeIdFluxUtilise))
		{
			if(!isset($this->listeIdFluxUtilise["id$id"]))
			{
				$trouver = true;
			}
			else
			{
				$id++;
			}
		}
		$this->listeIdFluxUtilise["id$id"] = $id;
	
		return $id;
	}

	
	/**
	 * fonction qui retourne le premier id non utilisé pour la table $table.
	 *  Lorsque l'on utilise cette fonction, l'id est automatiquement marqué comme utilisé.
	 * @return int
	 */
	public function getIdCategorieSuivant()
	{
		$id = 1; //id suivant potentiel. Si je le trouve dans le tableau, j'essaye le suivant
		$trouver = false;
		//j'essaie tous les id à partir de 1 et je teste s'il est dans la liste. S'il n'y est pas, ça sera la valeur de l'id suivant
		while(!$trouver && $id <= count($this->listeIdCategorieUtilise))
		{
			if(!isset($this->listeIdCategorieUtilise["id$id"]))
			{
				$trouver = true;
			}
			else
			{
				$id++;
			}
		}
		$this->listeIdCategorieUtilise["id$id"] = $id;
	
		return $id;
	}
	

	/**
	 * fonction qui crée le fichier de sauvegarde opml
	 */
	public function creeSaveOpml()
	{
		$nomFichier = "save.opml";
		$handle = @fopen(REPERTOIRE_SAUVEGARDE . $nomFichier, "w+");
		@fwrite($handle,$this->getOpml($nomFichier)->toXML());
		@fclose($handle);
	}


	/**
	 * fonction qui construit le contenu du fichier opml
	 * @param $nomFichier		String
	 * @return PageXML
	 */
	public function getOpml($nomFichier="save.opml")
	{
		$opml = new PageXML("opml");
		$opml->addAttribut("version", "2.0");

		$head = $opml->createElement("head");
		$head->createElement("title", $nomFichier);

		$head->createElement("dateCreated", date("r"));

		if($GLOBALS["config"]->getPseudo() != "")
		{
			$head->createElement("dateCreated", $GLOBALS["config"]->getPseudo());
		}

		$body = $opml->createElement("body");

		//on affiche d'abord la liste des flux sans catégorie
		$listeFlux = $this->getListeRss(0);
		if(count($listeFlux)>0)
		{
			foreach ($listeFlux as $fl)
			{
				$titre = ($fl->getTitle());
				$outline = $body->createElement("outline");
					
				//si un champ est vide, je mets un espace pour éviter de générer un fichier non valide avec un attribut sans valeur
				$outline->addAttribut("text", ($titre != "" ? $titre : " "))
					->addAttribut("htmlUrl", ($fl->getLink() != "" ? $fl->getLink() : " "))
					->addAttribut("title", ($titre != "" ? $titre : " "))
					->addAttribut("xmlUrl", ($fl->getUrlFlux() != "" ? $fl->getUrlFlux() : " "))
					->addAttribut("type", "rss")
					->addAttribut("version", "RSS");
			}
		}

		//on affiche les catégories
		if(count($this->listeCategorie)>0)
		{
			foreach($this->listeCategorie as $cat)
			{
				if($cat->getId() > 0)
				{
					$titre = $cat->getTitre();

					$outlinecat = $body->createElement("outline");
					$outlinecat->addAttribut("title", ($titre != "" ? $titre : "-"))
						->addAttribut("text", ($titre != "" ? $titre : "-"));

					//on affiche la liste des flux de cette catégorie
					$listeFlux = $this->getListeRss($cat->getId());
					if(count($listeFlux)>0)
					{
						foreach ($listeFlux as $fl)
						{
							$titre = ($fl->getTitle());
							$outline = $outlinecat->createElement("outline");
							$outline->addAttribut("text", ($titre != "" ? $titre : " "))
								->addAttribut("htmlUrl", ($fl->getLink() != "" ? $fl->getLink() : " "))
								->addAttribut("title", ($titre != "" ? $titre : " "))
								->addAttribut("xmlUrl", ($fl->getUrlFlux() != "" ? $fl->getUrlFlux() : " "))
								->addAttribut("type", "rss")
								->addAttribut("version", "RSS");
						}
					}
				}
			}
		}

		return $opml;
	}


	/**
	 * fonction qui va chercher le flux dont on connait l'id
	 * @param $idFlux		int	: id du flux
	 * @return Rss
	 */
	public function getFluxById($idFlux)
	{
		$flux = new Rss();

		if(count($this->liste) > 0)
		{
			foreach($this->liste as &$listeCat)
			{
				if(count($listeCat) > 0)
				{
					foreach($listeCat as &$rss)
					{
						if($rss->getId() == $idFlux)
						{
							return $rss;
						}
					}
				}
			}
		}
			
		return $flux;
	}


	/**
	 * fonction qui va chercher dans la base le flux dont on connait l'url
	 * @param $urlFlux		String	: url du flux
	 * @return Rss
	 */
	public function getFluxByUrl($urlFlux)
	{
		//on va parcourir tous les fichiers rss et s'arreter des qu'on trouve la meme url
		if(count($this->liste) >0)
		{
			//on parcours toutes les catégories
			foreach($this->liste as &$tabCat)
			{
				if(count($tabCat) >0)
				{
					//on parcours chaque flux de chaque catégorie
					foreach($tabCat as &$flux)
					{
						if($flux->getUrlFlux() == $urlFlux)
						{
							return $flux;
						}
					}
				}
			}
		}
		return new Rss();
	}


	/**
	 * fonction qui renvoi le flux rss suivant (ou précédant) d'une catégorie
	 * @param $rss		Rss		: flux dont on veut connaitre le suivant ou le précédant
	 * @param $prec		boolean	: sert a savoir si on veut le précédant ou le suivant
	 * @return Rss
	 */
	public function getFluxSuivant(Rss $rss, $prec = false)
	{
		foreach($this->liste[$rss->getIdCa()] as &$flux)
		{
			if((!$prec && $flux->getPosition() == ($rss->getPosition() + 1)) || ($prec && $flux->getPosition() == ($rss->getPosition() - 1)))
			{
				return $flux;
			}
		}
		return new Rss();
	}


	/**
	 * fonction qui retourne la position suivante dans une catégorie
	 * @param $idCat	int	: id de la catégorie dont on veut connaitre la position suivante
	 * @return int : position suivante de la catégorie
	 */
	public function getRssPositionSuivante($idCat)
	{
		if(isset($this->liste[$idCat]))
		{
			return count($this->liste[$idCat]) +1;
		}
		else
		{
			return 1;
		}
	}


	/**
	 * fonction qui décale les positions des flux d'une catégorie à partir d'une certaine position
	 */
	public function decalerFlux($idCat, $position)
	{
		for($i = $position; $i < count($this->liste[$idCat]); $i++)
		{
			$temp = &$this->liste[$idCat][$i];
			$temp->setPosition($temp->getPosition() -1);
			$temp->ecrireFichierRss();
		}
	}


	/**
	 * fonction qui va chercher la liste des flux d'une catégorie
	 * @param $idCat		int
	 * @return array(Rss)
	 */
	public function getListeRss($idCat)
	{
		if(count($this->liste)>0 && isset($this->liste[$idCat]))
		{
			return $this->liste[$idCat];
		}
		else
		{
			return array();
		}
	}
	
	
	/**
	 * méthode qui ajoute une nouvelle catégorie
	 * @param $nomCat
	 * @return id de la catégorie ajoutée
	 */
	public function ajouterCategorie($nomCat)
	{
		$catRss = new RssCategorie();
		$catRss->setTitre(trim($_POST['nomCategorie']));
		$catRss->enregistrer();

		return $catRss->getId();
	}
	
	
	
	public function ajouterFlux($nvlUrl, $prive)
	{
		//on vérifie dans la base si le flux existe déjà
		$flux = getFluxByUrl($nvlUrl);

		//s'il n'existe pas, on le crée
		if($flux->getId() == 0)
		{
			$flux = new Rss();
			$flux->setIdCa($cat);
			$flux->setUrlFlux($nvlUrl);
				
			if(!empty($prive))
			{
				$flux->setPrive(true);
			}
			$flux->enregistrer();
				
			$this->creeSaveOpml();
			
			$ch = curl_init($flux->getUrlFlux());
			curl_setopt($ch, CURLOPT_USERAGENT, $GLOBALS["userAgent"]);
			curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
			curl_setopt($ch, CURLOPT_TIMEOUT, $GLOBALS["timeoutCurl"]);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $GLOBALS["timeoutCurl"]);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);		
			$xmlStr = curl_exec($ch);
			curl_close($ch);
		
			//on actualise le flux pour récupérer les infos le concernant. Lors de l'ajout, on va essayer de récupérer le favicon
			$flux->actualiser($xmlStr, true);

			//on vérifie la cahérence entre le décalage entre la mise à jour de 2 flux et la fréquence de rafraichissement des flux
			if($config->verifCoherence() != "")
			{
				$config->ecrireFichierConf();
			}
			
			return true;
		}
		else
		{
			return false;
		}
	}
	
	
	
	public function deplaceFlux($idFlux, $monter)
	{
		$flux = $this->getFluxById($idFlux);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$fluxTemp = $this->getFluxSuivant($flux, $monter);	//true = flux précedent
			if($fluxTemp->getId()>0)
			{
				$posTemp = $fluxTemp->getPosition();
				$fluxTemp->setPosition($flux->getPosition());
				$flux->setPosition($posTemp);
				$fluxTemp->enregistrer();
				$flux->enregistrer();
				
				$GLOBALS["msg"] .= $GLOBALS["langue"]->get("MSG_FLUX_DEPLACE", $flux->getTitle());
			}
			else
			{
				$GLOBALS["msg"] .= $GLOBALS["langue"]->get("MSG_FLUX_PREMIER");
			}
		}
		else
		{
			$GLOBALS["msg"] .= $GLOBALS["langue"]->get("MSG_FLUX_INEXISTANT");
		}
		
		return $flux->getId();
	}
	
	
	
	public function deplacerCategorie($idCat, $monter)
	{
		
		$cat = getRssCategorieById($idCat);

		//on vérifie que la catégorie existe bien
		if($cat->getId()>0)
		{
			$catTemp = getRssCategorieSuivant($cat, $monter);
			if($catTemp->getId()>0)
			{
				$posTemp = $catTemp->getPosition();
				$catTemp->setPosition($cat->getPosition());
				$cat->setPosition($posTemp);
				$cat->enregistrer();
				$msg .= $GLOBALS["langue"]->get("MSG_CATEGORIE_DEPLACEE", $cat->getTitre());
			}
			else
			{
				$msg .= $GLOBALS["langue"]->get("MSG_CATEGORIE_PREMIERE");
			}
		}
		else
		{
			$msg .= $GLOBALS["langue"]->get("MSG_CATEGORIE_INEXISTANTE");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}


	/**
	 * fonction qui récupère une catégories de flux RSS
	 * @param $id			int
	 * @return RssCategorie
	 */
	public function getRssCategorieById($id)
	{
		foreach ($this->listeCategorie as &$cat)
		{
			if($cat->getId() == $id)
			{
				return $cat;
			}
		}
		return new RssCategorie();
	}


	/**
	 * fonction qui récupère une catégories suivante ou précédente d'une catégorie
	 * @param $rssCat     RssCategorie
	 * @param $prec       boolean : vrai = précédant, false = suivant
	 * @return RssCategorie
	 */
	public function getRssCategorieSuivant(RssCategorie $rssCat, $prec=false)
	{
		foreach ($this->listeCategorie as &$cat)
		{
			if(($prec && $cat->getPosition() == $rssCat->getPosition() - 1) || (!$prec && $cat->getPosition() == $rssCat->getPosition() + 1))
			{
				return $cat;
			}
		}
		return new RssCategorie();
	}


	/**
	 * fonction qui vérifie si une catégorie est vide
	 * @param RssCategorie	$rssCat
	 * @return boolean
	 */
	function RssCategorieVide(RssCategorie $rssCat)
	{
		return count($this->getListeRss($rssCat->getId())) == 0;
	}
	
	
	public function import()
	{
		$filename = basename( $_FILES['import']['name']);
		if( move_uploaded_file($_FILES['import']['tmp_name'], $filename))
		{
			$xmlLocal = new DOMDocument();
			$idCat = 0;
				
			//FIXME méthode qui ne me plait pas mais qui marche !!
			//Je fais ça à cause du caractère & qui pose problème.
			// On perd tous les caractères html, mais on les récupère apres en faisant l'opération inverse
			// Il doit bien y avoir un moyen de faire ça proprement!!!!
			$xmlStr = hackXlmNonValide(file_get_contents($filename), true);
				
			if(@$xmlLocal->loadXML($xmlStr, LIBXML_ERR_NONE))
			{
				foreach($xmlLocal->getElementsByTagName('outline') as $outline)
				{
					// s'il n'y pas d'attribut xmlUrl, c'est une catégorie
					if(count($outline->attributes->getNamedItem("xmlUrl")) == 0)
					{
						$catRss = new RssCategorie();
						$value = hackXlmNonValide($outline->attributes->getNamedItem("text")->nodeValue);
						$catRss->setTitre($value);
						$catRss->enregistrer();

						$idCat = $catRss->getId();
					}
					else
					{
						$url = $outline->attributes->getNamedItem("xmlUrl")->nodeValue;
						$flux = $this->getFluxByUrl($url);
						if($flux->getId() == 0)
						{
							$flux = new Rss();
							$flux->setUrlFlux($url);
							$flux->setIdCa($idCat);
							$value = hackXlmNonValide($outline->attributes->getNamedItem("text")->nodeValue);
							$flux->setTitle($value);
							$flux->enregistrer();
							//on actualise pas le flux lors de l'import car ça prendrait trop de temps d'ou un gros risque de timeout
						}
						else
						{
							$msg .= $GLOBALS["langue"]->get("MSG_FLUX_EXISTE", $flux->getTitle()) . "<br>\n";
						}
					}
				}
					
				$this->creeSaveOpml();

				//on vérifie la cahérence entre le décalage entre la mise à jour de 2 flux et la fréquence de rafraichissement des flux
				if($GLOBALS["config"]->verifCoherence() != "")
				{
					$GLOBALS["config"]->ecrireFichierConf();
				}
			}
			else
			{
				$msg .= $GLOBALS["langue"]->get("MSG_NON_VALIDE") . "<br>\n";
			}

			//le fichier à été lu jusqu'au bout, on peut le supprimer
			unlink($filename);
		}
		else
		{
			$msg .= $GLOBALS["langue"]->get("MSG_NON_RECUPERE") . "<br>\n";
		}
	}
	
	
	public function chargement()
	{
		$filename = basename( $_FILES['chargement']['name']);
		if( move_uploaded_file($_FILES['chargement']['tmp_name'], $filename))
		{
			$zip = new ZipArchive;
			if ($zip->open($filename) === true)
			{
				if(is_dir(REPERTOIRE_SAUVEGARDE))
				{
					rdelete(REPERTOIRE_SAUVEGARDE);
				}
				$zip->extractTo('.');
					
				$zip->close();

				$this->chargerListeFlux(true);
			}
			else
			{
				$msg .=  $GLOBALS["langue"]->get("MSG_NON_VALIDE") . "<br>\n";
			}

			//le fichier à été lu jusqu'au bout, on peut le supprimer
			unlink($filename);
		}
		else
		{
			$msg .=  $GLOBALS["langue"]->get("MSG_NON_RECUPERE") . "<br>\n";
		}
	}
	



	/**
	 * fonction qui va chercher le nombre d'item archivé d'une catégorie
	 * @param $idCat	int	: id de la catégorie
	 * @param $nonLu	boolean	: vrai si on veut inclure les items nouveaux
	 * @param $archive	boolean	: vrai si on veut inclure les items archivés
	 * @return int : nombre d'item
	 */
	public function nbItemArchiveCat($idCat, $nonLu=true, $archive=false)
	{
		$etat = array();
		if($nonLu)
		{
			$etat[] = RSS_NON_LU;
		}
		if($archive)
		{
			$etat[] = RSS_ARCHIVE;
		}

		$cpt = 0;

		if(isset($this->liste[$idCat]) && count(@$this->liste[$idCat])>0)
		{
			foreach($this->liste[$idCat] as $flux)
			{
				if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
				{
					foreach($flux->getListeItem() as $item)
					{
						if(in_array($item->getEtat(), $etat))
						{
							$cpt++;
						}
					}
				}
			}
		}

		return $cpt;
	}


	/**
	 * fonction qui va chercher le nombre d'item archivé
	 * @param $nbNonLu	boolean	: vrai si on veut inclure les items nouveaux
	 * @param $archive	boolean	: vrai si on veut inclure les items archivés
	 * @return int : nombre d'item
	 */
	public function nbItemArchiveTotal($nbNonLu=true, $archive=false)
	{
		$etat = array();
		if($nbNonLu)
		{
			$etat[] = RSS_NON_LU;
		}
		if($archive)
		{
			$etat[] = RSS_ARCHIVE;
		}

		$cpt = 0;

		if(count($this->liste)>0)
		{
			foreach($this->liste as $idCat=>$liste)
			{
				if(count($liste)>0)
				{
					foreach($liste as $flux)
					{
						if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
						{
							foreach($flux->getListeItem() as $item)
							{
								if(in_array($item->getEtat(), $etat))
								{
									$cpt++;
								}
							}
						}
					}
				}
			}
		}

		return $cpt;
	}


	/**
	 * fonction qui récupère la liste des items d'une catégorie
	 * @param $idCat	int		: id de la catégorie dont on veut récupérer les items archivés
	 * @param $etat	  String  : liste des états concernés
	 * @return array(RssItem)
	 */
	public function getListeItemCat($idCat, $listeEtat=array())
	{
		$listeItem = array();

		//une seule catégorie
		if($idCat >= 0)
		{
			if(isset($this->liste[$idCat]) && count($this->liste[$idCat])>0)
			{
				foreach($this->liste[$idCat] as $flux)
				{
					if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
					{
						foreach($flux->getListeItem() as $item)
						{
							if(in_array($item->getEtat(), $listeEtat ))
							{
								$listeItem[] = $item;
							}
						}
					}
				}
			}
		}

		//toutes les catégories
		elseif($idCat == -1)
		{
			if(count($this->liste)>0)
			{
				foreach($this->liste as $idCat=>$liste)
				{
					if(count($liste)>0)
					{
						foreach($liste as $flux)
						{
							if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
							{
								foreach($flux->getListeItem() as $item)
								{
									if(in_array($item->getEtat(), $listeEtat))
									{
										$listeItem[] = $item;
									}
								}
							}
						}
					}
				}
			}
		}
		return $listeItem;
	}


	/**
	 * fonction qui récupère la liste des items issu d'une recherche
	 * @param $recherche	  String  : recherche
	 * @return array(RssItem)
	 */
	public function getListeItemRecherche(FiltreRecherche $recherche)
	{
		$listeItem = array();

		//on récupère la saisie. La casse est déjà gérée dans l'objet lorsque je récupère cette saisie
		$mots = $recherche->getText();

		//on sépare les mots
		$listeMots = explode(" ", $mots);
		$nbMot = count($listeMots);

		$cpt = 0;

		if(count($this->liste)>0)
		{
			foreach ($this->liste as $idCat=>$listeCat)
			{
				foreach($listeCat as $flux)
				{
					if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
					{
						foreach($flux->getListeItem() as $item)
						{
							$trouver = 0;
							if(in_array($item->getEtat(), $recherche->getListeEtat()))
							{
								foreach($listeMots as $mot)
								{
									$titre = $item->getTitle();
									$desc = $item->getDescription();
									$listeTag = $item->getListeCategorie();
									if(!$recherche->getCaseSensitive())
									{
										$titre = strtolower($titre);
										$desc = strtolower($desc);
										$mot = strtolower($mot);
									}

									//si on trouve le mot dans le titre ou la description ou dans les tag si besoin
									if((!$recherche->getTag() && (strpos($titre, $mot) !== false || strpos($desc, $mot) !== false)) || ($recherche->getTag() && estDansTag($listeTag, $mot, $recherche->getCaseSensitive())))
									{
										if($recherche->getTousLesMots())
										{
											$trouver = $trouver + 1;
											if($trouver == $nbMot)
											{
												$listeItem[] = $item;
											}
										}
										else
										{
											$listeItem[] = $item;
											break;
										}
									}
								}
							}
						}
					}
				}
			}
		}

		return $listeItem;
	}
	
	
	public function enregistrer()
	{
		//on sauvegarde d'abord la liste des catégories
		$xml = new PageXML("liste");

		if(count($this->listeCategorie)>0)
		{
			usort($this->listeCategorie, "triCatParPosition");
				
			foreach($this->listeCategorie as $cat)
			{
				//si l'id vaut 0, on doit faire un ajout
				if($cat->getId() == 0)
				{
					//on vérifie que la catégorie n'existe pas encore
					$existe = false;
					if(count($this->listeCategorie)>0)
					{
						foreach($this->listeCategorie as $categorie)
						{
							if($categorie->getTitre() == $this->titre)
							{
								$this->setId($categorie->getId());
								$this->setPosition($categorie->getPosition());
								$existe = true;
								break;
							}
						}
					}

					//si elle n'existe pas, on peut l'ajouter
					if(!$existe)
					{
						$pos = 1;
						if(count($this->listeCategorie)>0)
						{
							usort($this->listeCategorie, "triCatParPosition");
							$temp = $this->listeCategorie[count($this->listeCategorie)-1];
							$pos = $temp->getPosition() +1;
						}
						$cat->setPosition($pos);
						$cat->setId($this->getIdCategorieSuivant());
						$this->listeCategorie[] = $cat;
					}
				}
		
				$xml->addElement($cat->getXML());
				
				


				//sauvegarde des flux de la catégorie
				foreach($this->liste[$cat->getId()] as $flux)
				{
					//si l'id vaut 0, on doit faire un ajout
					if($flux->getId() == 0)
					{
						$pos = 1;
						$liste = getListeRss($flux->idCat);
						if(count($liste)>0)
						{
							usort($this->liste[$flux->idCat], "triFluxParPosition");
							$g = $this->liste[$flux->idCat];
							$ind = count($g)-1;
							$temp = $g[$ind];

							$pos = $temp->getPosition() +1;
						}
						$flux->setPosition($pos);
						$flux->setId($this->getIdFluxSuivant());

						$this->liste[$this->idCat][] = $flux;
					}
					$flux->ecrireFichierRss();
				}
			}
		}
		
		$fichier = fopen(NOM_FICHIER_CATEGORIE, 'w+');
		fwrite($fichier, $xml->toXML());
		fclose($fichier);
	}
	//TODO sauver les flux sans catégories
}
?>
