<?php
/**
 * Le fichier de langue n'est pas obligatoire. Mais s'il est passé en paramètre, il doit contenir les index :
 *			CONNEXION_MAUVAIS_PASS
 *			CONNEXION_ACCES_REFUSE
 *			CONNEXION_CONNEXION_OK
 *			CONNEXION_DECONNEXION_OK
 *			CONNEXION_DECONNEXION
 *			CONNEXION_BTN_DECONNEXION
 *			CONNEXION_LBL_PASS
 *			CONNEXION_BTN_CONNEXION
 * 
 * utilisation :
 *	$connexion = new Connexion($langue, $nomSession);
 *
 *	//il faut appeller cette méthode pour gérer la connexion et la déconnexion
 *  $msg = $connexion->gererConnexion($votre_mot_de_passe_crypte);
 *  
 *  ...
 *  
 *  if($connexion->estConnecte())
 *  {
 *  	...
 *  }
 *	
 *	Le nombre max d'essai est défini par  $LOGIN_NB_ERREUR_MAX;
 *	Un fichier de log connexion est créé dans le respertoire "connexion" 
 *
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */
class Connexion
{
	public static $CHEMIN_BF = "connexion/";	//chemin du repertoire dans lequel sera sauvegardé les fichiers d'erreur de connexion
	public static $EXTENSION_BF = ".bf";		//extension des fichiers d'erreurs de connexion
	public static $LOGIN_NB_ERREUR_MAX =10;	//nombre de connexion max avant de bloquer l'acces au login

	private $nomSession = "nomSession";			//Clé du tableau de session qui sert a savoir si un utilisateur est connecté
	private $langue=array();					//tableau contenant les textes à afficher

	public function getNomSession(){return  $this->nomSession;}
	public function setNomSession($nomSession){$this->nomSession = $nomSession;}

	public function getLangue(){return  $this->langue;}
	public function setLangue($langue){$this->langue = $langue;}


	public function __construct($langue="", $nomSession="nomSession")
	{
		$this->setNomSession($nomSession);
		
		$array = array();
		if($langue instanceof Langue)
		{
			$array["CONNEXION_MAUVAIS_PASS"] = $langue->get("CONNEXION_MAUVAIS_PASS");
			$array["CONNEXION_ACCES_REFUSE"] = $langue->get("CONNEXION_ACCES_REFUSE");
			$array["CONNEXION_CONNEXION_OK"] = $langue->get("CONNEXION_CONNEXION_OK");
			$array["CONNEXION_DECONNEXION"] = $langue->get("CONNEXION_DECONNEXION");
			$array["CONNEXION_DECONNEXION_OK"] = $langue->get("CONNEXION_DECONNEXION_OK");
			$array["CONNEXION_BTN_DECONNEXION"] = $langue->get("CONNEXION_BTN_DECONNEXION");
			$array["CONNEXION_LBL_PASS"] = $langue->get("CONNEXION_LBL_PASS");
			$array["CONNEXION_BTN_CONNEXION"] = $langue->get("CONNEXION_BTN_CONNEXION");
		}
		else
		{
			$array["CONNEXION_MAUVAIS_PASS"] = "Mauvais mot de passe.";
			$array["CONNEXION_ACCES_REFUSE"] = "Acces refusé";
			$array["CONNEXION_CONNEXION_OK"] = "Connexion OK";
			$array["CONNEXION_DECONNEXION_OK"] = "Déconnexion OK";
			$array["CONNEXION_DECONNEXION"] = "Vous êtes maintenant déconnecté.";
			$array["CONNEXION_BTN_DECONNEXION"] = "Déconnexion";
			$array["CONNEXION_LBL_PASS"] = "Connexion";
			$array["CONNEXION_BTN_CONNEXION"] = "Mot de passe : ";
		}
		$this->setLangue($array);
	}


	/**
	 * fonction qui vérifie si on est connecté ou non à un site
	 * @return boolean : vrai si on est connecté
	 */
	public function estConnecte()
	{
		return (isset($_SESSION[$this->getNomSession()]) && $_SESSION[$this->getNomSession()] == true);
	}


	/**
	 * fonction qui gère la connexion et la déconnexion d'un site
	 * @param $pass			String : hash du mot de passe
	 * @param $sessionName	String : nom de la variable de session qui va determiner si on est connecter ou non au site
	 */
	public function gererConnexion($pass, $login="")
	{
		$msg = "";
		$cpt = 0;
		if(isset($_POST['password']) && ($login == "" || isset($_POST['login'])))
		{
			//on va faire les vérification d'usage anti brut force

			//on va charger(créer) le fichier correspondant au $sessionName
			$chemin = Connexion::$CHEMIN_BF . strtolower($this->getNomSession()) . Connexion::$EXTENSION_BF;
				
			//on vérifie que le fichier htaccess existe, sinon, on le crée
			verifHtaccess($chemin);

			if(file_exists($chemin))
			{
				//on récupère la date de dernier blocage et le nombre d'erreur de connexion
 				list($date_blocage, $cpt) = Connexion::lireFichierBF($chemin);
 				
				//si on change de jour, on initialise le compteur
				if($date_blocage != date("Y-m-d"))
				{
					$cpt = 0;
				}
			}

			//si on a pas encore atteind le quota de la journée, on vérifie le mot de passe
			if($cpt <= Connexion::$LOGIN_NB_ERREUR_MAX)
			{
				if(hashSB($_POST['password']) == $pass && ($login == "" || hashSB($_POST['login']) == $login))
				{
					$_SESSION[$this->getNomSession()] = true;
					$this->log($this->langue["CONNEXION_CONNEXION_OK"]);
				}
				else
				{
					$cpt++;
					Connexion::ecrireFichierBF($chemin,$cpt);
					$this->log($this->langue["CONNEXION_MAUVAIS_PASS"] . " : " . ($login == "" ? "" : $_POST['login'] . " / ") . $_POST['password']);
					$msg = $this->langue["CONNEXION_MAUVAIS_PASS"];
				}
			}
			else
			{
				$msg = $this->langue["CONNEXION_MAUVAIS_PASS"];
				$this->log($this->langue["CONNEXION_ACCES_REFUSE"] . " : " . ($login == "" ? "" : $_POST['login'] . " / ") . $_POST['password']);
			}
		}
		//ou se déconnecter
		elseif(isset($_POST['deconnexion']))
		{
			unset($_SESSION[$this->getNomSession()]);
			$this->log($this->langue["CONNEXION_DECONNEXION_OK"]);
			$msg = $this->langue["CONNEXION_DECONNEXION"];
		}
		return $msg;
	}
	
	
	/**
	 * fonction qui enregistre les logs de connexions
	 * @param $msg
	 * @return unknown_type
	 */
	protected function log($msg)
	{
		$date = date('Y-m-d H:i:s');
		$chemin = Connexion::$CHEMIN_BF . "connexion.log";
		
		//avant d'écrire ou de créer un fichier, on vérifie l'arborescence
		verifChemin($chemin);

		$fichierBf = @fopen($chemin, 'a+');
		//On écrit donc dans notre fichier
		@fwrite($fichierBf,$date . " [" . $_SERVER['REMOTE_ADDR'] . "] : " . $msg . "\n");
		@fclose($fichierBf);
	}


	/* Cette fonction nous permettra de lire notre fichier
	 * @param $chemin	String	: chemin vers le fichier qu'il faut lire
	 */
	static private function lireFichierBF($chemin)
	{
		$fichierBf = @fopen($chemin, 'r');
		$informationBf = @fgets($fichierBf);
		@fclose($fichierBf);

		//on récupére la date de dernier blocage et le nombre d'erreur de connexion
		return explode('--',$informationBf);
	}


	/* Cette fonction nous permettra d'écrire dans notre fichier
	 * @param $chemin	String	: chemin vers le fichier dans lequel il va falloir écrire
	 * @param $cpt		int		: nombre d'erreur de connexion sur le login
	 * @param $date		String	: date du dernier accès. Laisser à vide pour avoir la date du jour.
	 */
	static private function ecrireFichierBF($chemin,$cpt,$date="")
	{
		if($date == "")
		{
			$date = date('Y-m-d');
		}
		//avant d'écrire ou de créer un fichier, on vérifie l'arborescence
		verifChemin($chemin);

		$fichierBf = @fopen($chemin, 'w+');
		//On écrit donc dans notre fichier
		@fwrite($fichierBf,$date . "--" . $cpt);
		@fclose($fichierBf);
	}
}
?>
