<?php
/**
 * Le fichier de langue n'est pas obligatoire. Mais s'il est passé en paramètre, il doit contenir les index :
 * 	CONFIG_FORM_LOGO_LABEL
 *  CONFIG_FORM_LOGO_DESC
 * 	CONFIG_FORM_ERROR_LOGO_TRANSFERT
 *  CONFIG_FORM_ERROR_LOGO_FORMAT
 *  
 *  utilisation :
 *  
 *  $logo = new Logo($lang, $chemin);
 *  
 *  if($logo->verifUpload())
 *  {
 *  	...
 *  }
 *  else
 *  {
 *  	$msgErreur = $logo->getErreur();
 *  	...
 *  }
 *  
 *  
 *  Dans l'IHM
 *  	pour afficher le logo
 *  	$logo->toElement();
 *  
 *  
 *  	pour afficher le formulaire d'envoi :
 *  	$logo->getElementFormulaire();
 *  
 *  
 *  
 *
 *
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 */
class Logo {

	private static $LARGEUR_REFERENCE_LOGO = 80;
	private static $HAUTEUR_REFERENCE_LOGO = 80;

	private $langue = array();
	private $erreur = "";
	private $path = "";
	private $texteRemplacement = "";

	public function getLangue(){return  $this->langue;}
	public function setLangue($langue){ $this->langue = $langue;}

	public function getErreur(){return $this->erreur;}
	public function setErreur($erreur){$this->erreur = $erreur;}

	public function getPath(){return $this->path;}
	public function setPath($path){$this->path = $path;}

	public function getTexteRemplacement(){return $this->texteRemplacement;}
	public function setTexteRemplacement($texteRemplacement){$this->texteRemplacement = $texteRemplacement;}


	public function __construct($langue="", $chemin="")
	{
		$this->setPath($chemin);
		
		$array = array();
		if($langue instanceof Langue)
		{
			$array["CONFIG_FORM_LOGO_LABEL"] = $langue->get("CONFIG_FORM_LOGO_LABEL");
			$array["CONFIG_FORM_LOGO_DESC"] = $langue->get("CONFIG_FORM_LOGO_DESC");
			$array["CONFIG_FORM_ERROR_LOGO_TRANSFERT"] = $langue->get("CONFIG_FORM_ERROR_LOGO_TRANSFERT");
			$array["CONFIG_FORM_ERROR_LOGO_FORMAT"] = $langue->get("CONFIG_FORM_ERROR_LOGO_FORMAT");
		}
		else
		{
			$array["CONFIG_FORM_LOGO_LABEL"] = "Modifier le logo";
			$array["CONFIG_FORM_LOGO_DESC"] = "Vous êtes maintenant déconnecté.";
			$array["CONFIG_FORM_ERROR_LOGO_TRANSFERT"] = "Déconnexion";
			$array["CONFIG_FORM_ERROR_LOGO_FORMAT"] = "Connexion";
		}
		$this->setLangue($array);
	}


	/**
	 * méthode qui renvoie le code html pour afficher le logo.
	 * @return String
	 */
	public function toHTML()
	{
		$out = "";
		if($this->isLogoExiste())
		{
			$out = "<img src=\"" . $this->getPath() . "logo.png\" class=\"logo\" alt=\"" . $this->getTexteRemplacement() . "\">";
		}
		return $out;
	}


	/**
	 * méthode qui vérifie si le logo existe bien
	 * @return boolean
	 */
	public function isLogoExiste(){
		return file_exists($this->path . "/logo.png");
	}


	/**
	 * méthode qui va tenter de faire un upload du logo
	 * @return boolean : vrai si le fichier a bien été envoyé et redimmensionné
	 */
	public function verifUpload()
	{
		if(isset($_FILES['logo']) && $_FILES['logo']['name'] != "")
		{
			// vérification que le fichier envoyé est bien arrivé
			if($_FILES['logo']['error']==0)
			{
				//on stocke le fichier redimenssionné
				if($this->recupereLogo())
				{
					return true;
				}
			}
			else
			{
				$this->erreur = $this->langue["CONFIG_FORM_ERROR_LOGO_TRANSFERT"] . "<br>";
			}
		}

		return false;
	}


	/*
	 * méthode qui va récupérer et redimmensionner le logo
	 */
	function recupereLogo()
	{
		$filename = basename( $_FILES['logo']['name']);
		$extension = strtolower(pathinfo($filename, PATHINFO_EXTENSION));

		//on vérifie que le format est accepté. Je vérifie juste l'extension, normalement, ça devrait suffir
		if(in_array($extension, array("jpg","png","gif")))
		{
			//on redimmensionne le logo

			//lecture de l'image originale
			switch($extension)
			{
				case "jpg" :
					$source = @ImageCreateFromJpeg($_FILES['logo']['tmp_name']);
					break;
				case "png" :
					$source = @ImageCreateFromPng($_FILES['logo']['tmp_name']);
					break;
				case "gif" :
					$source = @ImageCreateFromGif($_FILES['logo']['tmp_name']);
					break;
			}

			//récupération des dimentions de l'image originale
			$largeurSource = imagesx($source);
			$hauteurSource = imagesy($source);

			//si une des 2 dimensions est trop grande, on va réduire la taille tout en gardant les proportions
			if($largeurSource > Logo::$LARGEUR_REFERENCE_LOGO || $hauteurSource > Logo::$HAUTEUR_REFERENCE_LOGO)
			{
				$ratioReference = Logo::$LARGEUR_REFERENCE_LOGO / Logo::$HAUTEUR_REFERENCE_LOGO;
				$ratio = $largeurSource / $hauteurSource;
				//si l'image est dans le sens de la hauteur, il faut redimentionner l'image avec la hauteur en reference
				if($ratio < $ratioReference)
				{
					//calcul des dimensions de l'image
					$hauteurDestination = Logo::$HAUTEUR_REFERENCE_LOGO;

					// Contraint le rééchantillonage à une largeur fixe
					// Maintient le ratio de l'image
					$largeurDestination = round(($hauteurDestination / $hauteurSource) * $largeurSource);
				}
				else
				{
					//calcul des dimensions de l'image
					$largeurDestination = Logo::$LARGEUR_REFERENCE_LOGO;

					// Contraint le rééchantillonage à une largeur fixe
					// Maintient le ratio de l'image
					$hauteurDestination = round(($largeurDestination / $largeurSource) * $hauteurSource);
				}
			}
			else
			{
				$hauteurDestination = $hauteurSource;
				$largeurDestination = $largeurSource;
			}

			//création de l'image redimensionnée
			$im =  imagecreatetruecolor ($largeurDestination, $hauteurDestination);

			//on met le background en transparent
			imagesavealpha($im, true);
			$background = imagecolorallocatealpha ($im ,0 ,127 ,0 ,127);
			imagefill( $im, 0, 0, $background );

			//copie de l'image redimensionnée dans le nouveau fichier
			ImageCopyResampled($im, $source, 0, 0, 0, 0, $largeurDestination, $hauteurDestination, $largeurSource, $hauteurSource);

			$fileSortie = $this->path . "/logo.png";
			//on supprime l'éventuel ancien logo
			if(file_exists($fileSortie))
			{
				unlink($fileSortie);
			}

			//enregistrement de l'image redimensionnée au format png pour garder l'éventuel transparence
			ImagePng ($im, $fileSortie);
			return true;
		}
		else
		{
			$this->erreur = $this->langue["CONFIG_FORM_ERROR_LOGO_FORMAT"] . "<br>";
		}
		return false;
	}
}
?>
