<?php
/**
 * 
 * 
 * @author superbaillot
 * 
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */
class RssCategorie
{
	private $id = 0;
	private $position = 0;
	private $titre = "";


	public function getId(){return $this->id;}
	public function setId($id){$this->id = $id;}

	public function getPosition(){return $this->position;}
	public function setPosition($position){$this->position = $position;}

	public function getTitre(){return $this->titre;}
	public function setTitre($titre){$this->titre = $titre;}



	/**
	 * fonction qui sauvegarde la catégorie dans un fichier
	 */
	public function enregistrer()
	{
		//si l'id vaut 0, on doit faire un ajout
		if($this->getId() == 0)
		{
			//on vérifie que la catégorie n'existe pas encore
			$existe = false;
			if(count($GLOBALS["listeCategorie"])>0)
			{
				foreach($GLOBALS["listeCategorie"] as $cat)
				{
					if($cat->getTitre() == $this->titre)
					{
						$this->setId($cat->getId());
						$this->setPosition($cat->getPosition());
						$existe = true;
						break;
					}
				}
			}

			//si elle n'existe pas, on peut l'ajouter
			if(!$existe)
			{
				$pos = 1;
				if(count($GLOBALS["listeCategorie"])>0)
				{
					usort($GLOBALS["listeCategorie"], "triCatParPosition");
					$temp = $GLOBALS["listeCategorie"][count($GLOBALS["listeCategorie"])-1];
					$pos = $temp->getPosition() +1;
				}
				$this->setPosition($pos);
				$this->setId(getIdSuivant($GLOBALS['arrayIdCategorie']));
				$GLOBALS["listeCategorie"][] = $this;
			}
		}
		ecrireListeCategorie();
	}


	/**
	 * fonction qui supprime une catégorie de la liste
	 */
	public function supprimer()
	{
		for($i=0 ; $i<count($GLOBALS["listeCategorie"]) ; $i++)
		{
			$catTemp = $GLOBALS["listeCategorie"][$i];
			if($catTemp->getId() == $this->getId())
			{
				unset($GLOBALS["listeCategorie"][$i]);

        //on libère l'id
     		if(isset($GLOBALS["arrayIdCategorie"]['id' . $this->id]))
     		{
           unset($GLOBALS["arrayIdCategorie"]['id' . $this->id]);
        }
        
				ecrireListeCategorie();
				break;
			}
		}
	}


	/**
	 * fonction qui charge l'objet
	 */
	public function chargerById()
	{
		if($this->getId() != 0)
		{
			foreach($GLOBALS["listeCategorie"] as $cat)
			{
				$cat = new RssCategorie();
				if($cat->getId() == $this->id)
				{
					$cat->getPosition() == $this->position;
					$cat->getTitre() == $this->titre;
					return true;
				}
			}
		}
		return false;
	}


	/**
	 * méthode qui construit le xml de l'objet
	 * @return DomElement
	 */
	public function getXML($xml)
	{	
		$cat = $xml->createElement("categorie");
		$cat->appendChild(getDomElement($xml, "id", $this->getId()));
		$cat->appendChild(getDomElement($xml, "position", $this->getPosition()));
		$cat->appendChild(getDomElement($xml, "titre", $this->getTitre(), true));

		return $cat;
	}
}


/**
 * fonction qui récupère une catégories de flux RSS
 * @param $id			int
 * @return RssCategorie
 */
function getRssCategorieById($id)
{
	foreach ($GLOBALS["listeCategorie"] as &$cat)
	{
		if($cat->getId() == $id)
		{
			return $cat;
		}
	}
	return new RssCategorie();
}


/**
 * fonction qui récupère une catégories suivante ou précédente d'une catégorie
 * @param $rssCat     RssCategorie
 * @param $prec       boolean : vrai = précédant, false = suivant
 * @return RssCategorie
 */
function getRssCategorieSuivant(RssCategorie $rssCat, $prec=false)
{
	foreach ($GLOBALS["listeCategorie"] as &$cat)
	{
		if(($prec && $cat->getPosition() == $rssCat->getPosition() - 1) || (!$prec && $cat->getPosition() == $rssCat->getPosition() + 1))
		{
			return $cat;
		}
	}
	return new RssCategorie();
}


/**
 * fonction qui vérifie si une catégorie est vide
 * @param RssCategorie	$rssCat
 * @return boolean
 */
function RssCategorieVide(RssCategorie $rssCat)
{
	//FIXME a mettre dans l'objet
	return count(getListeRss($rssCat->getId())) == 0;	
}


/**
 * fonction de tri des catégories par id
 * @param $c1	RssCategorie
 * @param $c2	RssCategorie
 * @return int
 */
function triCatParId(RssCategorie  $c1, RssCategorie $c2)
{
	if ($c1->getId() == $c2->getId())
	{
		return 0;
	}
	return ($c1->getId() < $c2->getId()) ? -1 : 1;
}

/**
 * fonction de tri des catégories par position
 * @param $c1	RssCategorie
 * @param $c2	RssCategorie
 * @return int
 */
function triCatParPosition(RssCategorie  $c1, RssCategorie $c2)
{
	if ($c1->getPosition() == $c2->getPosition())
	{
		return 0;
	}
	return ($c1->getPosition() < $c2->getPosition()) ? -1 : 1;
}


/**
 * fonction qui sauvegarde les listes des catégories dans un fichier xml
 */
function ecrireListeCategorie()
{
	if(isset($GLOBALS["listeCategorie"]))
	{
		$xml = new DOMDocument("1.0", "UTF-8");
		$xml->formatOutput = true;	//pour une indentation correcte (pas sur une seule ligne)
			
		$liste = $xml->createElement("liste");
		$xml->appendChild($liste);
		
		if(count($GLOBALS["listeCategorie"])>0)
		{
			usort($GLOBALS["listeCategorie"], "triCatParPosition");
				
			foreach($GLOBALS["listeCategorie"] as $cat)
			{
				$liste->appendChild($cat->getXML($xml));
			}
		}
		
		$fichier = fopen(NOM_FICHIER_CATEGORIE, 'w+');
		fwrite($fichier, $xml->saveXML());
		fclose($fichier);
	}
}
?>
