<?php
/**
 * 
 * 
 * @author superbaillot
 * 
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */
class RssItem
{
	private $id = 0;
	private $idFlux = 0;
	private $etat = 0;
	private $dateAffichee = "";

	private $title = "";
	private $link = "";
	private $description = "";

	private $author = "";
	private $category = "";
	private $comments = "";
	private $listeEnclosure = array();	//<enclosure url="http://www.scripting.com/mp3s/weatherReportSuite.mp3" length="12216320" type="audio/mpeg" />
	private $listeCategorie = array();
	private $guid = "";					//identifiant global unique
	private $pubDate = "";
	private $source = "";				//<source url="http://www.tomalak.org/links2.xml">Tomalak's Realm</source>

	public function getId(){return $this->id;}
	public function setId($id){$this->id = $id;}

	public function getIdFlux(){return $this->idFlux;}
	public function setIdFlux($idFlux){$this->idFlux = $idFlux;}

	public function getEtat(){return $this->etat;}
	public function setEtat($etat){$this->etat = $etat;}
	
	public function getDateAffichee(){return $this->dateAffichee;}
	public function setDateAffichee($dateAffichee){$this->dateAffichee = $dateAffichee;}

	public function getTitle(){return $this->title;}
	public function setTitle($title){$this->title = $title;}

	public function getLink(){return $this->link;}
	public function setLink($link){$this->link = $link;}

	public function getDescription(){return $this->description;}
	public function setDescription($description){$this->description = $description;}

	public function getAuthor(){return $this->author;}
	public function setAuthor($author){$this->author = $author;}

	public function getCategory(){return $this->category;}
	public function setCategory($category){$this->category = $category;}

	public function getComments(){return $this->comments;}
	public function setComments($comments){$this->comments = $comments;}

	public function getGuid(){return $this->guid;}
	public function setGuid($guid){$this->guid = $guid;}

	public function getPubDate(){return $this->pubDate;}
	public function setPubDate($pubDate){$this->pubDate = $pubDate;}

	public function getSource(){return $this->source;}
	public function setSource($source){$this->source = $source;}
	
	public function getListeEnclosure(){return $this->listeEnclosure;}
	public function setListeEnclosure($listeEnclosure){$this->listeEnclosure = $listeEnclosure;}
	
	public function getListeCategorie(){return $this->listeCategorie;}
	public function setListeCategorie($listeCategorie){$this->listeCategorie = $listeCategorie;}



	/**
	 * fonction qui construit le code xml
	 *
	 * @return DomElement
	 */
	public function toXML($xml)
	{
		$item = $xml->createElement("item");
		$item->appendChild(getDomElement($xml, "id", $this->getId()));
		$item->appendChild(getDomElement($xml, "etat", $this->getEtat()));
		$item->appendChild(getDomElement($xml, "title", $this->getTitle(), true));
		$item->appendChild(getDomElement($xml, "link", $this->getLink(), true));
		$item->appendChild(getDomElement($xml, "description", $this->getDescription(), true));
		$item->appendChild(getDomElement($xml, "pubDate", $this->getPubDate(), true));
		$item->appendChild(getDomElement($xml, "dateAffichee", $this->getDateAffichee(), true));
		$item->appendChild(getDomElement($xml, "guid", $this->getGuid(), true));
		if($this->getAuthor() != "")
		{
			$item->appendChild(getDomElement($xml, "author", $this->getAuthor(), true));
		}
		
		if(count($this->getListeEnclosure()) > 0)
		{
			foreach($this->getListeEnclosure() as $enclosure)
			{
				if($enclosure['url'] != "" && $enclosure['type'] != "")
				{
					$inclosure = $xml->createElement("enclosure");
					$item->appendChild($inclosure);
					$inclosure->setAttribute("url", $enclosure['url']);
					$inclosure->setAttribute("type", $enclosure['type']);
					if($enclosure['length'] != "")
					{
						$inclosure->setAttribute("length", $enclosure['length']);
					}
				}
			}
		}
		
		if(count($this->getListeCategorie()) > 0)
		{
			foreach($this->getListeCategorie() as $cat)
			{
				$item->appendChild(getDomElement($xml, "category", $cat, true));
			}
		}

		return $item;
	}
}


/**
 * fonction qui va chercher le nombre d'item archivé d'une catégorie
 * @param $idCat	int	: id de la catégorie
 * @param $nonLu	boolean	: vrai si on veut inclure les items nouveaux
 * @param $archive	boolean	: vrai si on veut inclure les items archivés
 * @return int : nombre d'item
 */
function nbItemArchiveCat($idCat, $nonLu=true, $archive=false)
{
	$etat = array();
	if($nonLu)
	{
		$etat[] = RSS_NON_LU;
	}
	if($archive)
	{
		$etat[] = RSS_ARCHIVE;
	}

	chargerListeFlux();
	$cpt = 0;

	if(isset($GLOBALS["listeFluxRss"][$idCat]) && count(@$GLOBALS["listeFluxRss"][$idCat])>0)
	{
		foreach($GLOBALS["listeFluxRss"][$idCat] as $flux)
		{
			if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
			{
				foreach($flux->getListeItem() as $item)
				{
					if(in_array($item->getEtat(), $etat))
					{
						$cpt++;
					}
				}
			}
		}
	}

	return $cpt;
}


/**
 * fonction qui va chercher le nombre d'item archivé
 * @param $nbNonLu	boolean	: vrai si on veut inclure les items nouveaux
 * @param $archive	boolean	: vrai si on veut inclure les items archivés
 * @return int : nombre d'item
 */
function nbItemArchiveTotal($nbNonLu=true, $archive=false)
{
	$etat = array();
	if($nbNonLu)
	{
		$etat[] = RSS_NON_LU;
	}
	if($archive)
	{
		$etat[] = RSS_ARCHIVE;
	}

	chargerListeFlux();
	$cpt = 0;
	
	if(count($GLOBALS["listeFluxRss"])>0)
	{
		foreach($GLOBALS["listeFluxRss"] as $idCat=>$liste)
		{
			if(count($liste)>0)
			{
				foreach($liste as $flux)
				{
					if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
					{
						foreach($flux->getListeItem() as $item)
						{
							if(in_array($item->getEtat(), $etat))
							{
								$cpt++;
							}
						}
					}
				}
			}
		}
	}

	return $cpt;
}


/**
 * fonction qui récupère la liste des items d'une catégorie
 * @param $idCat	int		: id de la catégorie dont on veut récupérer les items archivés
 * @param $etat	  String  : liste des états concernés
 * @return array(RssItem)
 */
function getListeItemCat($idCat, $listeEtat=array())
{
	$listeItem = array();

	chargerListeFlux();

	//une seule catégorie
	if($idCat >= 0)
	{
		if(isset($GLOBALS["listeFluxRss"][$idCat]) && count($GLOBALS["listeFluxRss"][$idCat])>0)
		{
			foreach($GLOBALS["listeFluxRss"][$idCat] as $flux)
			{
				if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
				{
					foreach($flux->getListeItem() as $item)
					{
						if(in_array($item->getEtat(), $listeEtat ))
						{
							$listeItem[] = $item;
						}
					}
				}
			}
		}
	}
	
	//toutes les catégories
	elseif($idCat == -1)
	{
		if(count($GLOBALS["listeFluxRss"])>0)
		{
			foreach($GLOBALS["listeFluxRss"] as $idCat=>$liste)
			{
				if(count($liste)>0)
				{
					foreach($liste as $flux)
					{
						if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
						{
							foreach($flux->getListeItem() as $item)
							{
								if(in_array($item->getEtat(), $listeEtat))
								{
									$listeItem[] = $item;
								}
							}
						}
					}
				}
			}
		}
	}
	return $listeItem;
}


/**
 * fonction qui récupère la liste des items issu d'une recherche
 * @param $recherche	  String  : recherche
 * @return array(RssItem)
 */
function getListeItemRecherche(FiltreRecherche $recherche)
{
	$listeItem = array();

	//on récupère la saisie. La casse est déjà gérée dans l'objet lorsque je récupère cette saisie
	$mots = $recherche->getText();

	//on sépare les mots
	$listeMots = explode(" ", $mots);
	$nbMot = count($listeMots);

	chargerListeFlux();
	$cpt = 0;
	
	if(count($GLOBALS["listeFluxRss"])>0)
	{
	foreach ($GLOBALS["listeFluxRss"] as $idCat=>$listeCat)
		{
			foreach($listeCat as $flux)
			{
				if($GLOBALS['connexion']->estConnecte() || !$flux->getPrive())
				{
					foreach($flux->getListeItem() as $item)
					{
						$trouver = 0;
						if(in_array($item->getEtat(), $recherche->getListeEtat()))
						{
							foreach($listeMots as $mot)
							{
								$mot = trim($mot);
								if($mot != "")
								{
									$titre = $item->getTitle();
									$desc = $item->getDescription();
									$listeTag = $item->getListeCategorie();
									if(!$recherche->getCaseSensitive())
									{
										$titre = strtolower($titre);
										$desc = strtolower($desc);
										$mot = strtolower($mot);
									}
		
									//si on trouve le mot dans le titre ou la description ou dans les tag si besoin
									if((!$recherche->getTag() && (strpos($titre, $mot) !== false || strpos($desc, $mot) !== false)) || ($recherche->getTag() && estDansTag($listeTag, $mot, $recherche->getCaseSensitive())))
									{
										if($recherche->getTousLesMots())
										{
											$trouver = $trouver + 1;
											if($trouver == $nbMot)
											{
												$listeItem[] = $item;
											}
										}
										else
										{
											$listeItem[] = $item;
											break;
										}
									}
								}
							}
						}
					}
				}
			}
		}
	}

	return $listeItem;
}


function estDansTag($arrayTag, $mot, $caseSensitive)
{
	if(count($arrayTag) > 0)
	{
		foreach($arrayTag as $tag)
		{
			if(!$caseSensitive)
			{
				$tag = strtolower($tag);
			}
			
			if(strpos($tag, $mot) !== false)
			{
				return true;
			}
		}
	}
	return false;
}


/**
 * fonction de tri des RssItem par id
 * @param $c1	RssItem
 * @param $c2	RssItem
 * @return int
 */
function triItemParId(RssItem   $c1, RssItem $c2)
{
	if ($c1->getId() == $c2->getId())
	{
		return 0;
	}
	return ($c1->getId() < $c2->getId()) ? -1 : 1;
}


/**
 * fonction de tri des RssItem du plus récent au plus ancien, en affichant d'abord les non lu, puis les archivé puis les lu
 * @param $c1	RssItem
 * @param $c2	RssItem
 * @return int
 */
function triRssItemParDateInverse(RssItem  $c1, RssItem $c2)
{
	if($c1->getEtat() == RSS_NON_LU && $c2->getEtat() != RSS_NON_LU)
	{
		return -1;
	}
	elseif($c2->getEtat() == RSS_NON_LU && $c1->getEtat() != RSS_NON_LU)
	{
		return 1;
	}
	elseif($c1->getEtat() == RSS_ARCHIVE && $c2->getEtat() != RSS_ARCHIVE)
	{
		return -1;
	}
	elseif($c2->getEtat() == RSS_ARCHIVE && $c1->getEtat() != RSS_ARCHIVE)
	{
		return 1;
	}
	elseif ($c1->getDateAffichee() == $c2->getDateAffichee())
	{
		return 0;
	}
	return ($c1->getDateAffichee() < $c2->getDateAffichee()) ? 1 : -1;
}


/**
 * fonction de tri des RssItem du plus ancien au plus récent, en affichant d'abord les non lu, puis les archivé puis les lu
 * @param $c1	RssItem
 * @param $c2	RssItem
 * @return int
 */
function triRssItemParDate(RssItem  $c1, RssItem $c2)
{
	if($c1->getEtat() == RSS_NON_LU && $c2->getEtat() != RSS_NON_LU)
	{
		return -1;
	}
	elseif($c2->getEtat() == RSS_NON_LU && $c1->getEtat() != RSS_NON_LU)
	{
		return 1;
	}
	elseif($c1->getEtat() == RSS_ARCHIVE && $c2->getEtat() != RSS_ARCHIVE)
	{
		return -1;
	}
	elseif($c2->getEtat() == RSS_ARCHIVE && $c1->getEtat() != RSS_ARCHIVE)
	{
		return 1;
	}
	elseif ($c2->getDateAffichee() == $c1->getDateAffichee())
	{
		return 0;
	}
	return ($c2->getDateAffichee() < $c1->getDateAffichee()) ? 1 : -1;
}
?>
