<?php
/**
 * Ce fichier contient les fonctions et constantes qui sont utiles au fonctionnement d'Aeres.
 * Pour être plus précis, sur mon serveur, j'utilise ces fonctions, constantes à plusieurs reprise. Elles sont donc défini dans des scripts accessible pour tous mes autres scripts. Comme je n'ai pas envi de tout dupliquer sur mon serveur (les images, les class.php, les css, ...) j'utilise toujours les mêmes. Ce script sert donc à redifinir certaines constantes et fonctions pour qu'Aeres marche en autonome.
 * 
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

define("CHEMIN_IMPORT_OM_CONFIGURATION", CHEMIN_IMPORT_OM_AERES . "configuration.class.php");
define("CHEMIN_IMPORT_OM_CONNEXION", CHEMIN_IMPORT_OM_AERES . "connexion.class.php");
define("CHEMIN_IMPORT_OM_LOGO", CHEMIN_IMPORT_OM_AERES . "logo.class.php");
define("CHEMIN_IMPORT_OM_FAVICON", CHEMIN_IMPORT_OM_AERES . "favicon.class.php");
define("CHEMIN_IMPORT_OM_LANGUE", CHEMIN_IMPORT_OM_AERES . "langue.class.php");
define("CHEMIN_SERVEUR","http://superbaillot.net");

define("CHEMIN_IMPORT_IMAGE", "DOC/images/");
define("CHEMIN_FAVICON_AERES", CHEMIN_IMPORT_IMAGE ."aeresFavicon.png");
define("CHEMIN_IMAGES_FEED", CHEMIN_IMPORT_IMAGE . "feed.png");
define("CHEMIN_IMAGES_FEED_VIDE", CHEMIN_IMPORT_IMAGE . "feedVide.png");
define("CHEMIN_CSS_DEFAULT", CHEMIN_CSS . "default.css");
define("CHEMIN_IMPORT_AWESOME_FONT", "DOC/font-awesome/css/font-awesome.min.css");



/**
 * Fonction qui vérifie si les répertoires du chemin spécifié existent.
 * S'ils n'existent pas, on les crée
 * @param $chemin	String	: chemin à vérifier. il peut s'agir d'un répertoire ou d'un fichier
 * @param $creation	boolean	: s'il s'agit d'un fichier, cet argument va définir s'il faut créer le fichier vide
 * @return boolean
 */
function verifChemin($chemin, $creation=false)
{
	$noProbleme = true;
	$listeRep = explode("/", $chemin);
	
	$nb = count($listeRep);
	
	$cheminVerif="";
	
	//on vérifie le chemin de tous les éléments sauf du dernier car le dernier peut être soit un répertoire, soit un fichier
	for($i=0; $i<$nb-1; $i++)
	{
		//on construit le chemin à vérifier.
		//On ajoute / pour séparer les répertoires uniquement si on est pas à la racine du répertoire à vérifier
		$cheminVerif = $cheminVerif . ($cheminVerif==""?"":"/") . $listeRep[$i];
		
		//si le répertoire à vérifier n'existe pas, on le crée
		if($cheminVerif != "" && !is_dir($cheminVerif))
		{
			$noProbleme = $noProbleme . mkdir($cheminVerif);
		}
	}
	
	//on va vérifier si le dernier élément est un fichier ou un répertoire. Pour cela on va chercher s'il existe un extension
	//si c'est un fichier et qu'il n'exite pas, on le crée vide
	//si c'est un répertoire et qu'il n'existe pas, on le crée
	$isRep = explode(".", $listeRep[$nb-1]);
	if(count($isRep)>1)
	{
		//si le fichier n'existe pas, on le crée
		if ($creation && !file_exists($chemin))
		{
		    $fichierBf = fopen($chemin, 'w+');
		    fwrite($fichierBf,"");
		    fclose($fichierBf);
		}
	}
	else
	{
		//si le répertoire à vérifier n'existe pas, on le crée
		if(!is_dir($chemin))
		{
			mkdir($chemin);
		}
	}	
}


/**
 * fonction qui crée le fichier .access dans le répertoire s'il n'existe pas encore
 * @param $chemin   Strong	: chemin du répertoire dans lequel on doit vérifier le fichier .access. Ce chemin peut être un chemin d'un fichier, dans ce cas, on regardera dans le répertoire contenant ce fichier
 * @param $htaccess	Strong	: contenu du fichier .access
 */
function verifHtaccess($chemin, $htaccess="deny from all\n")
{
	//on s'assure que tous les sous-répertoires existent
	verifChemin($chemin);

	//si le chemin n'indique pas un répertoire, on ne garde que le réptoire contenant le fichier
	if(!is_dir($chemin))
	{
		$pos=strrpos ($chemin, "/");
		$chemin = substr($chemin, 0, $pos);
	}

	//on construit le chemin vers le fichiers .htaccess : on ajoute un "/" a la fin du répertoire s'il n'y en a pas et si ce n'est pas le répertoire conurant
	if($chemin == "" || $chemin == "/")
	{
		$fileHtaccess = ".htaccess";
	}
	else
	{
		$fileHtaccess = $chemin . (strrpos($chemin, "/") + 1 == strlen($chemin) ? "" : "/") . ".htaccess";
	}

	//s'il n'y a pas encore de fichier .htaccess, on le crée
	if(!file_exists($fileHtaccess))
	{
		$fichier = @fopen($fileHtaccess, 'w+');
		@fwrite($fichier, $htaccess);
		@fclose($fichier);
	}
}


/**
 * fonction qui transforme les liens relatifs en absolue. Il faut pour cela spécifier quel attribut on veut changer
 * @param $html			String	: code html a surveiller
 * @param $racineSite	String	: racine du site pour transformer un chemin relatif en absolu
 * @param $att			String	: attribut a surveiller (src pour les image, href pour les liens)
 * @return String : code html corrigé
 */
function verifierLienRelatif($html, $racineSite, $att="src")
{
	$final = "";
	$posDebut = 0;
	$lgAtt = strlen($att);
	
	//je m'assure qu'il y ait bien un / a la fin
	if($racineSite[strlen($racineSite)-1] != "/")
	{
		$racineSite .= "/";
	}
	
	$posAtt = strpos($html, "$att=");
	while ($posAtt !== false)
	{
		//je sauvegarde tous ce qu'il y a avant
		$final .= substr($html, $posDebut, ($posAtt - $posDebut));
		
		//je mets a jour la position dans le cas ou je doivent sauvegarder ce qu'il reste à partir d'ici
		$posDebut = $posAtt;
		
		//cote ou double cote?
		$cote = "";
		
		$debutCote = strpos($html, '"', $posAtt+$lgAtt);
		if($debutCote !== false && ($debutCote - $posAtt-$lgAtt < 3))//je vérifie que la cote est bien assez proche de l'attribut
		{
			$cote =  '"';
		}
		else
		{
			$debutCote = strpos($html, "'", $posAtt+$lgAtt);
			if($debutCote !== false && ($debutCote - $posAtt-$lgAtt < 3))
			{
				$cote = "'";
			}
		}
		
		//j'initialise la fin de cote pour le cas ou elle ne soit pas la, je copirais donc le code restant
		$posFinCote = $posAtt+$lgAtt;
		
		//si j'ai déterminé se c'était une cote ou une double cote, je continu
		if($cote != "")
		{
			$posFinCote = strpos($html, $cote, $posAtt +$lgAtt+4);
			
			//si une fin de cote existe, je fais mes vérifications
			if($posFinCote !== false)
			{
				//on va extraire la valeur de l'attribut
				$posDebut = $posFinCote+1;
				$url = substr($html, $debutCote+1, $posFinCote - $debutCote-1);
				
				//si la valeur ne commence pas par http, cela signie que le chemin est relatif, on va donc le modifier en absolu
				//j'ai eu le cas ou le lien commence par // et ça marche
				if(substr($url, 0, 4) != "http" && substr($url, 0, 2) != "//")
				{
					if($url[0] == "/")
					{
						$url = substr($url, 1);
					}
					$url = $racineSite . $url;
				}
				$final .= " $att=\"$url\"";
			}
			else
			{
				$posFinCote = $posAtt+$lgAtt+1;
			}
		}
		$posAtt = strpos($html, "$att=", $posFinCote);
	}
	
	$final .= substr($html, $posDebut);
	
	return $final;
}


/**
 * fonction qui convertie une taille de fichier d'octet en kio, Mio, ...
 * @param $taille	int : taille en octet
 * @return String	taille + unité : taille en unité correcte
 */
function convertTaille($taille)
{
	$cpt = 0;
	$unite = " o";
	$tailleFinale = $taille;
	while($taille > pow(1024, $cpt))
	{
		$cpt++;
	}
	$tailleFinale =  round($taille/pow(1024, $cpt-1), 2);

	switch($cpt)
	{
		case 1 : $unite = " o";
		break;
		case 2 : $unite = " kio";
		break;
		case 3 : $unite = " Mio";
		break;
		case 4 : $unite = " Gio";
		break;
		case 5 : $unite = " Tio";
		break;
		default : $unite = " E" . 1000*($cpt - 5)/1024 . "Tio"; //c'est assez pourrie comme présentation, mais c'est correcte. Et je ne pense pas que ça va souvent me servir, alors je laisse comme ça
		break;
	}

	return $tailleFinale . $unite;
}


/**
 * fonction qui se retourne le hash d'un texte
 * @param $txt	String
 * @return String
 */
function hashSB($txt)
{
	return hash('sha256', $txt);
}


/**
 * fonction qui ajoute un répertoire dans une archive zip
 * @param $zip	ZipArchive	: archive zip
 * @param $src	String		: chemin du répertoire à ajouter
 * @param $dst	String		: chemin à l'intérieur du zip
 * @return boolean	: vrai si tout c'est bien passé
 */
function addRepZip(ZipArchive &$zip, $src, $dst="")
{
	$noProblem = true;
	
	if (is_dir($src))
	{
		//on va copier chaque répertoire et fichier de manière récursive
		$files = scandir($src);
		foreach ($files as $file)
		{
			// dans la liste, on aura forcément "." et "..". On va bien sur les éviter
			if ($file != "." && $file != "..")
			{
				$noProblem = $noProblem && addRepZip($zip, ($src == "" ? "" : "$src/") . $file, ($dst == "" ? "" : "$dst/") . $file);
			}
		}
	}
	//si c'est un fichier et qu'il existe bien, on le copie dans le zip
	else if (file_exists($src))
	{
		$noProblem = $zip->addFile($src, $dst);
	}
	
	return $noProblem;
}


/**
 * fonction de suppression récursive pour supprimer un repertoire et son contenu
 * @param $src	String : repretoire ou fichier à supprimer
 * @return Boolean : vrai si la suppression s'est effectuée dans la totalité
 */
function rdelete($src)
{
	$noProblem = true;
	
	//si c'est un répertoire, on doit d'abord le vider avant de le supprimer
	if (is_dir($src))
	{
		//on va parcourir tout le répertoire pour supprimer un à un tous les répertoires et fichiere
		$files = scandir($src);
		foreach ($files as $file)
		{
			//dans la liste, on aura forcément "." et "..", on va bien sur les ignorer
			if ($file != "." && $file != "..")
			{
				$noProblem = $noProblem && rdelete("$src/$file");
			}
		}
		$noProblem = $noProblem && rmdir($src);
	}
	
	//si c'est un fichier et qu'il existe, on le supprime
	else if (file_exists($src))
	{
		$noProblem = unlink($src);
	}

	return $noProblem;
}


/**
 *	fonction htmlentities avec les bon paramètre utf8
 * @param $texte	String
 * @return 	   String
 *	 
 */ 
function htmlentitiesUTF8($texte)
{
	return htmlentities($texte, ENT_COMPAT | ENT_HTML5, "UTF-8");
}


/**
 * fonction qui supprime les accents d'une chaine de caractère
 * @param $string		String	: chaine dont on veut supprimer les accents
 * @return String : chaine sans les accents
 */

function supprimeAccents($str, $charset='utf-8')
{
    $str = htmlentities($str, ENT_NOQUOTES, $charset);
    
    $str = preg_replace('#&([A-za-z])(?:acute|cedil|caron|circ|grave|orn|ring|slash|th|tilde|uml);#', '\1', $str);
    $str = preg_replace('#&([A-za-z]{2})(?:lig);#', '\1', $str); // pour les ligatures e.g. '&oelig;'
    $str = preg_replace('#&[^;]+;#', '', $str); // supprime les autres caractères
    
    return $str;
}
?>
