<?php
/**
 * -----------------------------------------------
 * ------------------- Aeres ---------------------
 * -----------------------------------------------
 *
 * Script qui me permet de suivre mes flux RSS.
 * Je voulais quelque chose de simple, sans base de données
 *
 * Copyright 2012-2013 Superbaillot
 * This file is part of Aeres.
 *
 *  Aeres is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Aeres is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Aeres.  If not, see <http://www.gnu.org/licenses/>.
 */

session_start();
//importation du fichier de configuration du site
require_once("Inc/aeresParametre.php");

//pour éviter un warning avec la fonction mktime
date_default_timezone_set($config->getTimezone());

define("VERSION_AERES", "3.0");					//version de Aeres
$nvlUrl = "";										//url à afficher dans l'input d'ajout de nouveau flux RSS
$idFlux = 0;										//id du flux actuelement affiché
$idCatAffichee = -1;								//id de la catégorie dont on veut afficher les éléments archivés (par défaut : -1 = toutes les catégories)
$idCatOuvert = 0;									//id de la catégorie dont on veut voir la liste des flux par défaut
$idItem = 0;										//id de l'item à charger via Ajax si on ne cherge pas les items par défaut
$itemDetailAffiche=false;							//définie si on doit afficher le détail d'un item dans le cas où on charge uniquement un item
$pageAAfficher = PAGE_LISTE;						//identifiant de la page a afficher (liste, popup, config,…)
$msg = "";											//message d'information à destination de l'utilisateur
$pageItem = 1;										//page des items de la catégorie
$categorieAAfficher = 0;							//catégorie à afficher
$arrayIdItem = array();								//sert à connaitre les id d'item utilisés
$arrayIdItemLibre = array();						//sert à connaitre l'id suivant des items
$arrayIdFlux =  array();							//sert à connaitre les id des flux utilisés pour trouver le suivant
$arrayIdCategorie =  array();						//sert à connaitre l'id suivant des categories
$listeCategorie = chargerCategorie();				//liste des catégories
$listeFluxRss = null;								//liste des flux (ils seront charger si on en a besoin)
$premiereConnexion = false;							//sert à savoir si c'est la première connexion
$recherche = new FiltreRecherche();					//recherche de l'utilisateur dans les items
$inverserTri = false;								//sert à savoir si l'utilisateur veut modifier le tri des items
$timeoutCurl = 30;									//timeout des requêtes curl pour les actualisations des flux
$listeFluxActualises =  array();					//liste des id des flux actualisés lors d'un rafraichissement de tous les flux
$flux = new Rss();
$connexion = new Connexion($langue, NOM_SESSION_RSS);
$listeEtat = array(RSS_NON_LU);						//liste des états afficher par défaut

if(!$config->getUniquementNonLu())
{
	$listeEtat[] = RSS_ARCHIVE;
}

$userAgent = "Aeres " . VERSION_AERES . " / agrégateur RSS de Superbaillot";
ini_set("user_agent",$userAgent);

//première instance de Aeres : on affiche la configuration avec un message d'info
if($config->getPassCrypte() == "" || $config->getPassCrypte() == hashSB(""))
{
	$premiereConnexion = true;
	$_POST['password'] = "";
	$pageAAfficher = PAGE_CONFIG;
	$msg = $langue->get("MSG_NO_PSWRD") . "<br>\n";
}

//la page "à propos" est accessible même non connecté (contrairement aux autres pages)
if(isset($_GET['page']) && $_GET['page'] == PAGE_APROPOS)
{
	$pageAAfficher = PAGE_APROPOS;
}

//on vérifie si on doit se connecter ou se déconnecter
$msg .= $connexion->gererConnexion($config->getPassCrypte());

//on réaffiche par défaut le dernier flux affiché
if(isset($_SESSION["idFluxAffiche"]))
{
	$idFlux = $_SESSION["idFluxAffiche"];
}

//on réaffiche par défaut la dernière catégorie affichée
if(isset($_SESSION["idCatAff"]))
{
	$idCatAffichee = $_SESSION["idCatAff"];
}

//on récupère la liste des état actuellement affichée
if(isset($_SESSION["s_listeEtat"]))
{
	$listeEtat = $_SESSION["s_listeEtat"];
}

//si l'utilisateur ne veut voir les items d'état particulier
if(isset($_POST['etat']))
{
	$liste = explode(',', $_POST['etat']);
	$pageAAfficher = PAGE_DETAIL_FLUX;
	$listeEtat = array();
	foreach ($liste as $et)
	{
		if(is_numeric($et) && $et <= MAX_ETAT_RSS)
		{
			$listeEtat[] = $et;
		}
	}
}

//si l'utilisateur veut inverser le tri de la page
if(isset($_POST['inverseTri']))
{
	if($_POST['inverseTri'] == "true")
	{
		$inverserTri =true;
	}
	$pageAAfficher = PAGE_DETAIL_FLUX;
}

//si l'utilisateur a choisi de visualiser les items d'un flux
if(!empty($_POST['fluxAffiche']) && is_numeric($_POST['fluxAffiche']))
{
	$idFlux = $_POST['fluxAffiche'];

	//on affiche les items d'un flux, donc pas d'une catégorie
	$idCatAffichee = 0;
	$pageAAfficher = PAGE_DETAIL_FLUX;
}

//si l'utilisateur a choisi de visualiser les éléments d'une catégorie
elseif(!empty($_POST['fluxCatAffiche']) && is_numeric($_POST['fluxCatAffiche']))
{
	$idCatAffichee = $_POST['fluxCatAffiche'];

	//on affiche les items d'une catégorie, donc pas d'un flux
	$idFlux = 0;
	$pageAAfficher = PAGE_DETAIL_FLUX;
}

//si on doit rafraichir le flux affiché
elseif(!empty($_POST['actualiserFlux']) && is_numeric($_POST['actualiserFlux']))
{
	$idCatAffichee = 0;
	$pageAAfficher = PAGE_DETAIL_FLUX;
	$flux = getFluxById($_POST['actualiserFlux']);
	
	//si l'id correspond bien à un flux, on rafraichi le flux en mettant à jour le favicon
	if($flux->getId() > 0)
	{
		$ch = curl_init($flux->getUrlFlux());
		curl_setopt($ch, CURLOPT_USERAGENT, $userAgent);
		curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
		curl_setopt($ch, CURLOPT_TIMEOUT, $timeoutCurl);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeoutCurl);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);		
		$xmlStr = curl_exec($ch);
		curl_close($ch);

		$flux->actualiser($xmlStr, true);
	}
	else
	{
		$msg = $langue->get("MSG_FLUX_INEXISTANT");
	}
}

//si on doit rafraichir des flux qui ne sont pas affichés (un rafraichissement automatique du flux)
elseif(isset($_GET['idFlux']))
{
	$pageAAfficher = PAGE_ACTUALISER_FLUX;
	
	$listeFluxActualises = explode(",", $_GET['idFlux']);
	
	// Création du gestionnaire multiple
	$mh = curl_multi_init();
	
	//servira pour les traitements qui seront fait une fois que tous les sites auront répondus
	$listeCurl = array();
	
	foreach($listeFluxActualises as $idFl)
	{
		$flux = getFluxById(trim($idFl));
		if($flux->getId() > 0)
		{
			if($flux->peutActualiser())
			{
				$ch = curl_init($flux->getUrlFlux());
				curl_setopt($ch, CURLOPT_USERAGENT, $userAgent);
				curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
				curl_setopt($ch, CURLOPT_TIMEOUT, $timeoutCurl);
				curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeoutCurl);
				curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
				
				$listeCurl[] = array("flux" => $flux, "curl" => $ch);
				
				curl_multi_add_handle($mh,$ch);
			}
		}
	}

	$running = null;
	do
	{
		curl_multi_exec($mh,$running);
		usleep(10000); // 10 ms
	}
	while($running > 0);

	//traitement des résultats
	foreach($listeCurl as $lc)
	{
		$flux = $lc["flux"];
		$xmlStr = curl_multi_getcontent($lc["curl"]);
		$strCurlError = curl_error($lc["curl"]);
		if($strCurlError != "")
		{
			$flux->setEtat(RSS_NON_ACCESSIBLE);
			$flux->enregistrer();
		}
		else
		{
			$flux->actualiser($xmlStr, $config->getRafraichirFavicon());
		}
		curl_multi_remove_handle($mh,$lc["curl"]);
	}
	curl_multi_close($mh);
	
	$config->setDateDerniereMAJ(date("d/m/Y H:i:s"));
	$config->ecrireFichierConf();
}

elseif(isset($_GET["cron"]))
{
	if($_GET["cron"] == substr($config->getPassCrypte(), 20))
	{
		//si c'est la tache cron qui est lancée, il faut charger tous les flux, même si on est pas connecté
		chargerListeFlux(true, true);

		$mh = curl_multi_init();

		//servira pour les traitements qui seront fait une fois que tous les sites auront répondus
		$listeCurl = array();

		$cpt = 0;	//compteur de flux à actualiser simultanément
		$timeRef = microtime (true);	//pour mes tests, pour voir le temps que ça prend pour rafraichir tous les flux
		
		foreach($listeFluxRss as $listeCat)
		{
			foreach($listeCat as $flux)
			{
				@set_time_limit(160);	//@ pour les serveur qui ne l'autorise pas
				if($flux->peutActualiser())
				{
					$cpt++;
					$ch = curl_init($flux->getUrlFlux());
					curl_setopt($ch, CURLOPT_USERAGENT, $userAgent);
					curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
					curl_setopt($ch, CURLOPT_TIMEOUT, $timeoutCurl);
					curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeoutCurl);
					curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	
					$listeCurl[] = array("flux" => $flux, "curl" => $ch);
	
					curl_multi_add_handle($mh,$ch);
				}

				if($cpt > $config->getNbRafraichissement())
				{
					$cpt = 0;
					$running = null;
					do
					{
						curl_multi_exec($mh,$running);
						usleep(10000); // 10 ms
					}
					while($running > 0);

					//traitement des résultats
					foreach($listeCurl as $lc)
					{
						$flux = $lc["flux"];
						$xmlStr = curl_multi_getcontent($lc["curl"]);
						$strCurlError = curl_error($lc["curl"]);
						if($strCurlError != "")
						{
							$flux->setEtat(RSS_NON_ACCESSIBLE);
							$flux->enregistrer();
						}
						else
						{
							$flux->actualiser($xmlStr, $config->getRafraichirFavicon());
						}
						curl_multi_remove_handle($mh,$lc["curl"]);
					}
					$listeCurl = array();
				}
			}
		}

		//si il reste des flux ont été mis dans le curl multi, mais que ce dernier n'a pas été exécuté
		if($cpt > 0)
		{
			$cpt = 0;
			$running = null;
			do
			{
				curl_multi_exec($mh,$running);
				usleep(10000); // 10 ms
			}
			while($running > 0);

			//traitement des résultats
			foreach($listeCurl as $lc)
			{
				$flux = $lc["flux"];
				$xmlStr = curl_multi_getcontent($lc["curl"]);
				$strCurlError = curl_error($lc["curl"]);
				if($strCurlError != "")
				{
					$flux->setEtat(RSS_NON_ACCESSIBLE);
					$flux->enregistrer();
				}
				else
				{
					$flux->actualiser($xmlStr, $config->getRafraichirFavicon());
				}
				curl_multi_remove_handle($mh,$lc["curl"]);
			}
			$listeCurl = array();
		}

		curl_multi_close($mh);

		$config->setDateDerniereMAJ(date("d/m/Y H:i:s"));
		$config->ecrireFichierConf();

		//FIXME pour les tests
		$timeRefFin = microtime (true);
		$duree = $timeRefFin - $timeRef;
		
		echo $langue->get("MSG_CRON_TERMINE", $duree);
	}
	else
	{
		echo $langue->get("MSG_CRON_KO");
	}
	exit;
}

//si on fait une recherche
elseif(isset($_POST['recherche']))
{
	try
	{
		$recherche->setText($_POST['recherche']);
		$idCatAffichee = 0;
		$idFlux = 0;
		$recherche->checkFormulaire();
	}
	catch (Exception $e)
	{
		$msg = $e->getMessage();
	}
	$pageAAfficher = PAGE_RECHERCHE;
}

//si on doit afficher le détail d'un item (cas qui ne se produit que si l'utilisateur a choisi de ne pas charger les détails par défaut)
elseif(isset($_POST['idItem']) && is_numeric($_POST['idItem']))
{
	$idItem = $_POST['idItem'];
	if(isset($_POST['afficheDetail']) && $_POST['afficheDetail'] == "true")
	{
		$itemDetailAffiche = true;
		$info = explode(".", $idItem);
		$flux = getFluxById($info[0]);
		$item = $flux->getItemById($info[1]);
		//si on marque automatiquement comme lu les items affichés
		if($config->getDetailLu() && $item->getEtat() == RSS_NON_LU)
		{
			$item->setEtat(RSS_LU);
			$flux->enregistrer();
		}
	}
	else
	{
	}
	$pageAAfficher = PAGE_DETAIL_ITEM;
}

//si on vient d'afficher le popup d'ajout de nouveau flux
if(!empty($_GET['newUrl']))
{
	$nvlUrl = $_GET['newUrl'];
	$pageAAfficher = PAGE_POPUP_AJOUT_RSS;
}

//on vérifie si on a tenté d'ajouter un lien via le popup. Dans ce cas, soit on réussi et on raffiche le formulaire avec un message de confirmation
//soit on a au moins un champ qui n'est pas correct et on raffiche le formulaire tel qu'il a été saisi pour que l'utilisateur puisse corriger l'erreur.
//donc on sauvegarde les info saisient par l'utilisateur
if(isset($_POST['popup']) && $_POST['popup'] == "true")
{
	$pageAAfficher = PAGE_POPUP_AJOUT_RSS;
	$nvlUrl = $_POST['newUrl'];
	$categorieAAfficher = $_POST['categorie'];
}

//si on est connecté, on a le droit de faire des actions
if($connexion->estConnecte())
{
	chargerListeFlux();
	//si c'est la première fois qu'on charge la page en étant connecté, je vérifie si une nouvelle version est disponible
	if($config->getCheckMaj() && !isset($_SESSION['premiereConnexionAeres']))
	{
		// pour ne plus faire cette vérification
		$_SESSION['premiereConnexionAeres'] = true;
		
		//on va chercher le numéro de la dernière version
		$handle = file(URL_CHECK_MAJ);
		$version = trim($handle[0]);
		
		if($version != "" && $version != VERSION_AERES)
		{
			$msg .= "<a href='" . URL_AERES_ARCHIVE . "'>" . $langue->get("MSG_NOUVELLE_VERSION", $version) . "</a><br>";
		}
	}

	//si l'utilisateur veut changer de page (dans le menu)
	if(!empty($_GET['page']) && !$premiereConnexion)
	{
		if(is_numeric($_GET['page'])&& $_GET['page'] >0 && $_GET['page']<= MAX_PAGE_RSS)
		{
			$pageAAfficher = $_GET['page'];
		}
		else
		{
			$msg = $langue->get("MSG_PAGE_INEXISTANTE");
		}
	}

	//récupération de la catégorie sélectionnée
	$cat = 0;
	if(isset($_POST['categorie']) && is_numeric($_POST['categorie']))
	{
		$cat = $_POST['categorie'];

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on doit ajouter une nouvelle catégorie
	if(!empty($_POST['nomCategorie']))
	{
		$catRss = new RssCategorie();
		$catRss->setTitre(trim($_POST['nomCategorie']));
		$catRss->enregistrer();

		$cat = $catRss->getId();

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on ajoute un nouveau flux
	if(!empty($_POST['newUrl']))
	{
		$nvlUrl = $_POST['newUrl'];
		//on vérifie dans la base si le flux existe déjà
		$flux = getFluxByUrl($nvlUrl);

		//s'il n'existe pas, on le crée
		if($flux->getId() == 0)
		{
			$flux = new Rss();
			$flux->setIdCa($cat);
			$flux->setUrlFlux($nvlUrl);
				
			if(!empty($_POST['prive']))
			{
				$flux->setPrive(true);
			}
			$flux->enregistrer();
				
			creeSaveOpml();

			$ch = curl_init($flux->getUrlFlux());
			curl_setopt($ch, CURLOPT_USERAGENT, $userAgent);
			curl_setopt($ch, CURLOPT_FRESH_CONNECT, true);
			curl_setopt($ch, CURLOPT_TIMEOUT, $timeoutCurl);
			curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeoutCurl);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);		
			$xmlStr = curl_exec($ch);
			curl_close($ch);
		
			//on actualise le flux pour récupérer les infos le concernant. Lors de l'ajout, on va essayer de récupérer le favicon
			$flux->actualiser($xmlStr, true);
			$msg .= $langue->get("MSG_FLUX_AJOUTE", $flux->getTitle());

			//on vérifie la cohérence entre le décalage entre la mise à jour de 2 flux et la fréquence de rafraichissement des flux
			$config->verifCoherence();
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_EXISTE", $flux->getTitle());
		}

		//si on vient du popup, on réaffiche le popup
		if(isset($_POST['popup']))
		{
			$pageAAfficher = PAGE_POPUP_AJOUT_RSS;
		}
		//sinon, on est donc dans la page de options
		else
		{
			$pageAAfficher = PAGE_OPTION_RSS;
			$idFlux = $flux->getId();
		}
	}

	//si on doit marquer des éléments d'un flux comme lus
	elseif(!empty($_POST['lu']))
	{
		//si on a utiliser le bouton d'un item pour le marque comme lu, on ne charge que le détail de cet item, pas toute la liste des items
		if($pageAAfficher != PAGE_DETAIL_ITEM)
		{
			$pageAAfficher = PAGE_DETAIL_FLUX;
		}

		//$_POST['lu'] est une liste des items cochés
		$listeLu = explode(",", $_POST['lu']);
		foreach($listeLu as $idLu)
		{
			//$idLu est en fait l'id du flux et l'id de l'item dans le flux
			$info = explode(".", $idLu);
			$flux = getFluxById($info[0]);
			$item = $flux->getItemById($info[1]);

			$item->setEtat(RSS_LU);
			$flux->enregistrer();
		}
	}

	//si on doit marquer des éléments d'un flux comme non lus
	elseif(!empty($_POST['nonLu']))
	{
		//si on a utiliser le bouton d'un item pour le marque comme non lu, on ne charge que le détail de cet item, pas toute la liste des items
		if($pageAAfficher != PAGE_DETAIL_ITEM)
		{
			$pageAAfficher = PAGE_DETAIL_FLUX;
		}

		//$_POST['nonLu'] est une liste des items cochés
		$listeLu = explode(",", $_POST['nonLu']);
		foreach($listeLu as $idLu)
		{
			//$idLu est en fait l'id du flux et l'id de l'item dans le flux
			$info = explode(".", $idLu);
			$flux = getFluxById($info[0]);
			$item = $flux->getItemById($info[1]);
			$item->setEtat(RSS_NON_LU);
			$flux->enregistrer();
		}
	}

	//si on doit marquer des éléments d'un flux comme archivés
	elseif(!empty($_POST['archive']))
	{
		//si on a utiliser le bouton d'un item pour le marque comme archivé, on ne charge que le détail de cet item, pas toute la liste des items
		if($pageAAfficher != PAGE_DETAIL_ITEM)
		{
			$pageAAfficher = PAGE_DETAIL_FLUX;
		}

		//$_POST['archive'] est une liste des items cochés
		$liste = explode(",", $_POST['archive']);
		foreach($liste as $id)
		{
			//$id est en fait l'id du flux et l'id de l'item dans le flux
			$info = explode(".", $id);
			$flux = getFluxById($info[0]);
			$item = $flux->getItemById($info[1]);
			$item->setEtat(RSS_ARCHIVE);
			$flux->enregistrer();
		}
	}

	//si on doit marquer tous les éléments d'un flux comme lus
	elseif(isset($_POST['toutLuFlux']) && is_numeric($_POST['toutLuFlux']) && $_POST['toutLuFlux'] > 0)
	{
		$pageAAfficher = PAGE_DETAIL_FLUX;

		$flux = getFluxById($_POST['toutLuFlux']);
		$listeItem = $flux->getListeItemByEtat(array(RSS_NON_LU));

		if(count($listeItem) > 0)
		{
			foreach($listeItem as $item)
			{
				$item->setEtat(RSS_LU);
			}
			$flux->enregistrer();
		}
	}

	//si on doit marquer tous les éléments d'une catégorie comme lus
	elseif(isset($_POST['toutLuCat']) && is_numeric($_POST['toutLuCat']) && $_POST['toutLuCat'] > 0)
	{
		$pageAAfficher = PAGE_DETAIL_FLUX;

		$liste = getListeRss($_POST['toutLuCat']);

		if(count($liste) > 0)
		{
			foreach($liste as $flux)
			{
				$listeItem = $flux->getListeItemByEtat(array(RSS_NON_LU));
				if(count($listeItem) > 0)
				{
					foreach($listeItem as $item)
					{
						$item->setEtat(RSS_LU);
					}
					$flux->enregistrer();
				}
			}
		}
	}

	//si on doit marquer tous les éléments comme lus
	elseif(isset($_POST['toutLuCat']) && is_numeric($_POST['toutLuCat']) && $_POST['toutLuCat'] == -1)
	{
		$pageAAfficher = PAGE_DETAIL_FLUX;

		if(count($listeFluxRss) > 0)
		{
			foreach($listeFluxRss as $idC=>$liste)
			{
				if(count($liste) > 0)
				{
					foreach($liste as $flux)
					{
						$listeItem = $flux->getListeItemByEtat(array(RSS_NON_LU));
						if(count($listeItem) > 0)
						{
							foreach($listeItem as $item)
							{
								$item->setEtat(RSS_LU);
							}
							$flux->enregistrer();
						}
					}
				}
			}
		}
	}

	//si on doit monter un flux dans la liste
	elseif(!empty($_POST['fluxUp']) && is_numeric($_POST['fluxUp']))
	{
		$flux = getFluxById($_POST['fluxUp']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$fluxTemp = getFluxSuivant($flux, true);	//true = flux précedent
			if($fluxTemp->getId()>0)
			{
				$posTemp = $fluxTemp->getPosition();
				$fluxTemp->setPosition($flux->getPosition());
				$flux->setPosition($posTemp);
				$fluxTemp->enregistrer();
				$flux->enregistrer();
				chargerListeFlux(true);
				$msg .= $langue->get("MSG_FLUX_DEPLACE", $flux->getTitle());
			}
			else
			{
				$msg .= $langue->get("MSG_FLUX_PREMIER");
			}
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit descendre un flux dans la liste
	elseif(!empty($_POST['fluxDown']) && is_numeric($_POST['fluxDown']))
	{
		$flux = getFluxById($_POST['fluxDown']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$fluxTemp = getFluxSuivant($flux);
			if($fluxTemp->getId()>0)
			{
				$posTemp = $fluxTemp->getPosition();
				$fluxTemp->setPosition($flux->getPosition());
				$flux->setPosition($posTemp);
				$fluxTemp->enregistrer();
				$flux->enregistrer();
				chargerListeFlux(true);
				$msg .= $langue->get("MSG_FLUX_DEPLACE", $flux->getTitle());
			}
			else
			{
				$msg .= $langue->get("MSG_FLUX_DERNIER");
			}
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit mettre un flux en privé
	elseif(!empty($_POST['idFluxPrive']) && is_numeric($_POST['idFluxPrive']))
	{
		$flux = getFluxById($_POST['idFluxPrive']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$flux->setPrive(!$flux->getPrive());
			$flux->enregistrer();

			chargerListeFlux(true);

			$msg .= $langue->get(($flux->getPrive() ? "MSG_FLUX_PRIVE_OK" : "MSG_FLUX_PRIVE_OK"), $flux->getTitle());
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit supprimer un favicon
	elseif(!empty($_POST['suppFavicon']) && is_numeric($_POST['suppFavicon']))
	{
		$flux = getFluxById($_POST['suppFavicon']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			if($flux->getFavicon() != "")
			{
				if(file_exists(CHEMIN_FAVICON . $flux->getFavicon()))
				{
					$fichier = unlink(CHEMIN_FAVICON . $flux->getFavicon());
				}
				$flux->setFavicon("");
				$flux->enregistrer();
				chargerListeFlux(true);
			}
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit changer un flux de catégorie
	elseif(!empty($_POST['idFluxEdit']) && is_numeric($_POST['idFluxEdit']) && is_numeric($_POST['newFluxCat']))
	{
		$flux = getFluxById($_POST['idFluxEdit']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$pos = $flux->getPosition();
			$idCat = $flux->getIdCa();

			$flux->setIdCa($_POST['newFluxCat']);
			$flux->setPosition(getRssPositionSuivante($_POST['newFluxCat']));
			$flux->enregistrer();

			//on met à jour les positions
			decalerFlux($idCat, $pos);

			chargerListeFlux(true);
				
			creeSaveOpml();
			$msg .= $langue->get("MSG_FLUX_DEPLACE", $flux->getTitle());
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit changer un flux de catégorie
	elseif(!empty($_POST['idFluxEdit']) && is_numeric($_POST['idFluxEdit']) && is_numeric($_POST['frequence']))
	{
		$flux = getFluxById($_POST['idFluxEdit']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$flux->setFequenceMaj($_POST['frequence']);
			$flux->enregistrer();

			chargerListeFlux(true);
				
			creeSaveOpml();
			$msg .= $langue->get("MSG_FLUX_FREQUENCE_MAJ", $flux->getTitle(), $_POST['frequence']);
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
		$idFlux = $flux->getId();
	}

	//si on doit supprimer un flux
	elseif(!empty($_POST['fluxSupprimer']) && is_numeric($_POST['fluxSupprimer']))
	{
		$flux = getFluxById($_POST['fluxSupprimer']);

		//on vérifie que le flux existe bien
		if($flux->getId()>0)
		{
			$pos = $flux->getPosition();
			$idCatOuvert = $flux->getIdCa();

			//on va supprimer le flux
			$flux->supprimer();
			chargerListeFlux(true);
				
			creeSaveOpml();
			$msg .= $langue->get("MSG_FLUX_SUPPRIME", $flux->getTitle());
		}
		else
		{
			$msg .= $langue->get("MSG_FLUX_INEXISTANT");
		}

		//on est donc danc dans la page de options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on doit monter une catégorie dans la liste
	elseif(!empty($_POST['catUp']) && is_numeric($_POST['catUp']))
	{
		$cat = getRssCategorieById($_POST['catUp']);

		//on vérifie que la catégorie existe bien
		if($cat->getId()>0)
		{
			$catTemp = getRssCategorieSuivant($cat, true);
			if($catTemp->getId()>0)
			{
				$posTemp = $catTemp->getPosition();
				$catTemp->setPosition($cat->getPosition());
				$cat->setPosition($posTemp);
				$cat->enregistrer();
				$msg .= $langue->get("MSG_CATEGORIE_DEPLACEE", $cat->getTitre());
			}
			else
			{
				$msg .= $langue->get("MSG_CATEGORIE_PREMIERE");
			}
		}
		else
		{
			$msg .= $langue->get("MSG_CATEGORIE_INEXISTANTE");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on doit descendre une catégorie dans la liste
	elseif(!empty($_POST['catDown']) && is_numeric($_POST['catDown']))
	{
		$cat = getRssCategorieById($_POST['catDown']);

		//on vérifie que la catégorie existe bien
		if($cat->getId()>0)
		{

			$catTemp = getRssCategorieSuivant($cat);
			if($catTemp->getId()>0)
			{
				$posTemp = $catTemp->getPosition();
				$catTemp->setPosition($cat->getPosition());
				$cat->setPosition($posTemp);
				$cat->enregistrer();
				$msg .= $langue->get("MSG_CATEGORIE_DEPLACEE", $cat->getTitre());
			}
			else
			{
				$msg .= $langue->get("MSG_CATEGORIE_DERNIERE");
			}
		}
		else
		{
			$msg .= $langue->get("MSG_CATEGORIE_INEXISTANTE");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on doit supprimer une catégorie
	elseif(!empty($_POST['catSupprimer']) && is_numeric($_POST['catSupprimer']))
	{
		$cat = getRssCategorieById($_POST['catSupprimer']);

		//on vérifie que la catégorie existe bien
		if($cat->getId()>0)
		{
			if(RssCategorieVide($cat))
			{
				//on va supprimer la catégorie
				$cat->supprimer();
					
				creeSaveOpml();
				$msg .= $langue->get("MSG_CATEGORIE_SUPPRIMEE", $cat->getTitre());
			}
			else
			{
				$msg .= $langue->get("MSG_CATEGORIE_NON_VIDE", $cat->getTitre());
			}
		}
		else
		{
			$msg .= $langue->get("MSG_CATEGORIE_INEXISTANTE");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si on doit éditer une catégorie
	elseif(!empty($_POST['catEdit']) && is_numeric($_POST['catEdit']))
	{
		if(!empty($_POST['catEditValeur']))
		{
			$cat = getRssCategorieById($_POST['catEdit']);
			$cat->setTitre($_POST['catEditValeur']);
			$cat->enregistrer();
				
			creeSaveOpml();
			$msg = $langue->get("MSG_CATEGORIE_RENOMMEE", $cat->getTitre());
		}
		else
		{
			$msg = $langue->get("MSG_CATEGORIE_SANS_NOM");
		}

		//on est donc dans dans la page des options
		$pageAAfficher = PAGE_OPTION_RSS;
	}

	//si l'utilisateur veut faire un export au format opml
	elseif(isset($_POST['export']) && $_POST['export'] == "true")
	{
		$pageAAfficher = PAGE_EXPORT;
	}

	//si l'utilisateur veut faire un import au format opml
	elseif(isset($_FILES['import']))
	{
		$pageAAfficher = PAGE_OPTION_RSS;

		$filename = basename( $_FILES['import']['name']);
		if( move_uploaded_file($_FILES['import']['tmp_name'], $filename))
		{
			import($filename);
			
			creeSaveOpml();
			
			//le fichier à été lu jusqu'au bout, on peut le supprimer
			unlink($filename);
		}
		else
		{
			$msg .= $langue->get("MSG_NON_RECUPERE") . "<br>\n";
		}
	}

	//si l'utilisateur veut faire une sauvegarde
	elseif(isset($_POST['sauvegarde']) && $_POST['sauvegarde'] == "true")
	{
		$pageAAfficher = PAGE_SAUVEGARDE;
	}

	//si l'utilisateur veut charger un fichier sauvegardé
	elseif(isset($_FILES['chargement']))
	{
		$pageAAfficher = PAGE_OPTION_RSS;

		$filename = basename( $_FILES['chargement']['name']);
		if( move_uploaded_file($_FILES['chargement']['tmp_name'], $filename))
		{
			$zip = new ZipArchive;
			if ($zip->open($filename) === true)
			{
				if(is_dir(REPERTOIRE_SAUVEGARDE))
				{
					rdelete(REPERTOIRE_SAUVEGARDE);
				}
				$zip->extractTo('.');
					
				$zip->close();

				chargerListeFlux(true);
			}
			else
			{
				$msg .= $langue->get("MSG_NON_VALIDE") . "<br>\n";
			}

			//le fichier à été lu jusqu'au bout, on peut le supprimer
			unlink($filename);
		}
		else
		{
			$msg .= $langue->get("MSG_NON_RECUPERE") . "<br>\n";
		}
	}

	//si on doit mettre à jour la configuration (je vérifie que le pseudo, ce n'est pas trés rigoureux, mais je pense que cela ne devrait pas poser de problème)
	elseif(isset($_POST['pseudo']))
	{
		$msg = $config->maj();
	}
}
else
{
	chargerListeFlux();
}

//si l'utilisateur veut affiché une page d'item particulier
if(isset($_POST['pageItem']) && is_numeric($_POST['pageItem']))
{
	$pageItem = $_POST['pageItem'];
	
	if(isset($_POST['recherche']))
	{
		$recherche = unserialize($_SESSION["rechercheRss"]);
		$pageAAfficher = PAGE_RECHERCHE;
	}
}

//on sauvegarde en variable de session l'id du flux ou de la catégorie affiché actuellement ainsi que les états affichés pour le réafficher en cas de rafrachissement de la page
$_SESSION["idFluxAffiche"] = $idFlux;
$_SESSION["idCatAff"] = $idCatAffichee ;
$_SESSION["s_listeEtat"] = $listeEtat;
$_SESSION["rechercheRss"] = serialize($recherche);


/************************************************    Génération de la page      **************************************************/

//code HTML de la page
switch($pageAAfficher)
{
	case PAGE_LISTE :
		require(REPERTOIRE_VUE . "pageFlux.php");
		break;
	case PAGE_DETAIL_FLUX :
		require(REPERTOIRE_VUE . "/xmlDetailFlux.php");
		break;
	case PAGE_POPUP_AJOUT_RSS :
		require(REPERTOIRE_VUE . "pagePopup.php");
		break;
	case PAGE_OPTION_RSS :
		require(REPERTOIRE_VUE . "pageGerer.php");
		break;
	case PAGE_CONFIG :
		require(REPERTOIRE_VUE . "pageConfiguration.php");
		break;
	case PAGE_ACTUALISER_FLUX :
		require(REPERTOIRE_VUE . "xmlActualiserFlux.php");
		break;
	case PAGE_EXPORT :
		echo getXMLExport();
		break;
	case PAGE_SAUVEGARDE :
		getZipSauvegarde();
		break;
	case PAGE_APROPOS :
		require(REPERTOIRE_VUE . "pageAPropos.php");
		break;
	case PAGE_RECHERCHE :
		require(REPERTOIRE_VUE . "xmlRecherche.php");
		break;
	case PAGE_DETAIL_ITEM :
		require(REPERTOIRE_VUE . "xmlDetailItem.php");
		break;
}

/************************************************     fonctions diverses      **************************************************/

/**
 * fonction qui construit et envoie le fichier OPML d'export de la liste des flux RSS
 * @return PageXML
 */

function getXMLExport()
{
	//on signale au navigateur qu'on lui renvoie un fichier xml
	$date = date('Ymd-His');
	header("Content-disposition: attachment; filename=aeres$date.opml");
	header("Content-Type: application/force-download");
	header("Content-Transfer-Encoding: text/xml\n");
	header("Pragma: no-cache");
	header("Cache-Control: must-revalidate, post-check=0, pre-check=0, public");
	header("Expires: 0");

	//on rempli le fichier xml
	return getOpml("aeres$date.opml");
}


function import($filename, $afficheMessage=true)
{
	global $idCat;
	global $msg;
	global $config;
	global $langue;
	
	$xmlLocal = new DOMDocument();
	$idCat = 0;
	$msgCom = "";
	//FIXME méthode qui ne me plait pas mais qui marche !! On perd tous les caractères html, mais on les récupère apres en faisant l'opération inverse
	// Il doit bien y avoir un moyen de faire ça proprement!!!!
	$xmlStr = hackXlmNonValide(file_get_contents($filename), true);

	if(@$xmlLocal->loadXML($xmlStr, LIBXML_ERR_NONE))
	{
		foreach($xmlLocal->getElementsByTagName('outline') as $outline)
		{
			// s'il n'y pas d'attribut xmlUrl, c'est une catégorie
			if(count($outline->attributes->getNamedItem("xmlUrl")) == 0)
			{
				$catRss = new RssCategorie();
				$value = hackXlmNonValide($outline->attributes->getNamedItem("text")->nodeValue);
				$catRss->setTitre($value);
				$catRss->enregistrer();

				$idCat = $catRss->getId();
			}
			else
			{
				$url = hackXlmNonValide($outline->attributes->getNamedItem("xmlUrl")->nodeValue);
				$flux = getFluxByUrl($url);
				if($flux->getId() == 0)
				{
					$flux = new Rss();
					$flux->setUrlFlux($url);
					$flux->setIdCa($idCat);
					$value = hackXlmNonValide($outline->attributes->getNamedItem("text")->nodeValue);
					$flux->setTitle($value);
					$flux->enregistrer();
					$msgCom .= $langue->get("MSG_FLUX_AJOUTE", $flux->getTitle()) . "<br>\n";
					//on actualise pas le flux lors de l'import car ça prendrait trop de temps d'où un gros risque de timeout
				}
				else
				{
					if($afficheMessage)
					{
						$msg .= $langue->get("MSG_FLUX_EXISTE", $flux->getTitle()) . "<br>\n";
					}
				}
			}
		}
		if($afficheMessage)
		{
			$msg .= $msgCom;
		}

		//on vérifie la cohérence entre le décalage entre la mise à jour de 2 flux et la fréquence de rafraichissement des flux
		if($config->verifCoherence() != "")
		{
			$config->ecrireFichierConf();
		}
		return true;
	}
	else
	{
		if($afficheMessage)
		{
			$msg .= $langue->get("MSG_NON_VALIDE") . "<br>\n";
		}
		return false;
	}
}

/**
 * fonction qui va faire un zip du répertoire Save et l'envoyer
 */
function getZipSauvegarde()
{
	//je crée l'archive dans Inc pour que le fichier temporaire ne soit pas public. (grâce au htaccess)
	$filename = "./Inc/aeres.zip";
	if(file_exists($filename))
	{
		unlink($filename);
	}

	$zip = new ZipArchive();

	if ($zip->open($filename, ZIPARCHIVE::CREATE)!==true)
	{
		exit("Impossible d'ouvrir le fichier <$filename>\n");
	}

	addRepZip($zip, "./Save", "Save");

	$zip->close();

	$nomArchive = "Aeres_" . date("Y-m-d") . ".zip";
	//on va envoyer le fichier
	header('Pragma: public');
	header('Cache-Control: must-revalidate, pre-check=0, post-check=0, max-age=0');
	header('Content-Tranfer-Encoding: none');
	header('Content-Length: ' . filesize($filename));
	header('Content-Type: application/octetstream; name="' . $nomArchive . '"');
	header('Content-Disposition: attachment; filename="' . $nomArchive . '"');
	header('Date: ' . gmdate(DATE_RFC1123));
	readfile($filename);

	//je supprime le fichier du serveur
	unlink($filename);

	exit; // nécessaire pour être certain de ne pas envoyer de fichier corrompu

}


/**
 * fonction qui construit le contenu du fichier opml
 * @param $nomFichier		String
 * @return String
 */
function getOpml($nomFichier="save.opml")
{
	$out = "<?xml version='1.0' encoding='UTF-8'?>
<opml version=\"2.0\">
	<head>
		<title>$nomFichier</title>
		<dateCreated>" . date("r") . "</dateCreated>\n";

	if($GLOBALS["config"]->getPseudo() != "")
	{
		$out .= "		<ownerName>" . $GLOBALS["config"]->getPseudo() . "</ownerName>\n";
	}
	$out .= "	</head>
	<body>\n";

	//on affiche d'abord la liste des flux sans catégorie
	$listeFlux = getListeRss(0);
	if(count($listeFlux)>0)
	{
		foreach ($listeFlux as $fl)
		{
			//si un champ est vide, je mets un espace pour éviter de générer un fichier non valide avec un attribut sans valeur
			$titre = ($fl->getTitle() != "" ? $fl->getTitle() : " ");
			$out .= "		<outline text=\"$titre\" htmlUrl=\"" . ($fl->getLink() != "" ? $fl->getLink() : " ") . "\" title=\"$titre\" xmlUrl=\"" . ($fl->getUrlFlux() != "" ? $fl->getUrlFlux() : " ") . "\" type=\"rss\" version=\"RSS\"/>\n";
		}
	}

	//on affiche les catégories
	if(count($GLOBALS["listeCategorie"])>0)
	{
		foreach($GLOBALS["listeCategorie"] as $cat)
		{
			if($cat->getId() > 0)
			{
				$titre = ($cat->getTitre() != "" ? $cat->getTitre() : "-");
				$out .= "		<outline title=\"$titre\" text=\"$titre\">\n";

				//on affiche la liste des flux de cette catégorie
				$listeFlux = getListeRss($cat->getId());
				if(count($listeFlux)>0)
				{
					foreach ($listeFlux as $fl)
					{
						$titre = ($fl->getTitle() != "" ? $fl->getTitle() : " ");
						$out .= "			<outline text=\"$titre\" htmlUrl=\"" . ($fl->getLink() != "" ? $fl->getLink() : " ") . "\" title=\"$titre\" xmlUrl=\"" . ($fl->getUrlFlux() != "" ? $fl->getUrlFlux() : " ") . "\" type=\"rss\" version=\"RSS\"/>\n";
					}
				}
				$out .= "		</outline>\n";
			}
		}
	}
	$out .= "	</body>
</opml>";

	return $out;
}


/**
 * formate un timestamp au format type "dimanche 5 févirier 2011 à 12h48)
 * @param $time		int	: timestamp
 * @return String : la date au bon format (voir ci-dessus)
 */
function formatDate($time)
{
	$date = "";
	switch (date("N", $time))
	{
		case 1 : $date .= $GLOBALS["langue"]->get("LUNDI");
		break;
		case 2 : $date .= $GLOBALS["langue"]->get("MARDI");
		break;
		case 3 : $date .= $GLOBALS["langue"]->get("MERCREDI");
		break;
		case 4 : $date .= $GLOBALS["langue"]->get("JEUDI");
		break;
		case 5 : $date .= $GLOBALS["langue"]->get("VENDREDI");
		break;
		case 6 : $date .= $GLOBALS["langue"]->get("SAMEDI");
		break;
		case 7 : $date .= $GLOBALS["langue"]->get("DIMANCHE");
		break;
	}
	$date .= " " . date("d", $time) . " ";
	switch (date("n", $time))
	{
		case 1 : $date .= $GLOBALS["langue"]->get("JANVIER");
		break;
		case 2 : $date .= $GLOBALS["langue"]->get("FEVRIER");
		break;
		case 3 : $date .= $GLOBALS["langue"]->get("MARS");
		break;
		case 4 : $date .= $GLOBALS["langue"]->get("AVRIL");
		break;
		case 5 : $date .= $GLOBALS["langue"]->get("MAI");
		break;
		case 6 : $date .= $GLOBALS["langue"]->get("JUIN");
		break;
		case 7 : $date .= $GLOBALS["langue"]->get("JUILLET");
		break;
		case 8 : $date .= $GLOBALS["langue"]->get("AOUT");
		break;
		case 9 : $date .= $GLOBALS["langue"]->get("SEPTEMBRE");
		break;
		case 10 : $date .= $GLOBALS["langue"]->get("OCTOBRE");
		break;
		case 11 : $date .= $GLOBALS["langue"]->get("NOVEMBRE");
		break;
		case 12 : $date .= $GLOBALS["langue"]->get("DECEMBRE");
		break;
	}
	$date .= " " . date(" Y " . $GLOBALS["langue"]->get("A") . " H\hi", $time) . " ";

	return $date;
}


/**
 * fonction qui va récupérer le favicon d'un site s'il existe
 * @param $flux	Rss	: flux url du site dont on veut récupérer le favicon
 * @return String : url du favicon
 */
function getFaviconRss(Rss $flux)
{
	$nomFichier = "";
	$urlSite = $flux->getUrlFlux();
	if($flux->getLink() != "")
	{
		$urlSite = $flux->getLink();
	}

	$favIcon = new Favicon($urlSite);
	$urlFav = $favIcon->getFavicon();

	//si on a un favicon, on le copie
	if($urlFav != "")
	{
		//on va inserer l'id dans le nom pour pouvoir différentier chaque favicon
		$nomFichier = pathinfo($urlFav, PATHINFO_FILENAME) . $flux->getId() . "." . pathinfo($urlFav, PATHINFO_EXTENSION);

		$newfile = CHEMIN_FAVICON . $nomFichier;
		verifChemin($newfile);

		//s'il n'existe pas, on crée le .htaccess qui autorise l'acces aux favicon (il y a une autre .htaccess plus bat dans la hierarchie qui interdit l'acces à tous les fichiers par défaut)
		verifHtaccess(CHEMIN_FAVICON, "allow from all\n");

		copy($urlFav, $newfile);
	}

	return $nomFichier;
}


/**
 * fonction qui va charger les catégories sauvegardées dans le fichier
 * @return array ( RssCategorie )
 */
function chargerCategorie()
{
	$liste = array();
	if(file_exists(NOM_FICHIER_CATEGORIE))
	{
		$xmlLocal = new DOMDocument();
		if(@$xmlLocal->load(NOM_FICHIER_CATEGORIE))
		{
			foreach($xmlLocal->getElementsByTagName('categorie') as $xmlCat)
			{
				$cat = new RssCategorie();
				$cat->setId($xmlCat->getElementsByTagName('id')->item(0)->nodeValue);
				$cat->setPosition($xmlCat->getElementsByTagName('position')->item(0)->nodeValue);
				$cat->setTitre($xmlCat->getElementsByTagName('titre')->item(0)->nodeValue);
				$liste[] = $cat;

				//on va remplir le tableau "arrayIdCategorie" pour pouvoir connaitre facilement l'id suivant intelligent
				$GLOBALS['arrayIdCategorie']['id' . $cat->getId()] = $cat->getId();
			}
		}
		usort($liste, "triCatParPosition");
	}
	return $liste;
}


/**
 * fonction qui va charger la liste des flux en scannant tous les fichiers xml
 * @return array( int=> array( int=> Rss ) )
 */
function chargerListeFlux($force = false, $forceChargerTout=false)
{
	//si on a déjà charger $GLOBALS["listeFluxRss"], on ne rescanne pas sauf cas de force majeur
	if ($GLOBALS["listeFluxRss"] == null || $force)
	{
		verifChemin(CHEMIN_FLUX);
		$GLOBALS["listeCategorie"] = chargerCategorie();

		//dans le repertoire de sauvegarde des flux, on va parcourir tous les fichiers pour charger les flux
		$listeCat = array();
		$listeCorrompu = array();
		$liste = scandir(CHEMIN_FLUX);
		//si on a des fichiers xml, on va les charger (le 2 correspond à . et ..)
		if(count($liste) > 2)
		{
			foreach($liste as $fichier)
			{
				//on ne se préocupe que des fichiers xml
				if(pathinfo($fichier, PATHINFO_EXTENSION) == "xml")
				{
					$rss = new Rss();
					$rss->chargerFichier(CHEMIN_FLUX . $fichier);
					//on vérifie qu'on a bien pû charger le fichier
					if($rss->getUrlFlux() != "")
					{
						if($forceChargerTout || $GLOBALS["connexion"]->estConnecte() || !$rss->getPrive())
						{
							$listeCat[$rss->getIdCa()][] = $rss;

							//on repère les id déjà utilisés dans 'arrayIdFlux' pour pouvoir facilement récupérer l'id suivant
							$GLOBALS["arrayIdFlux"]['id' . $rss->getId()] = $rss->getId();
						}
					}
					else
					{
						$listeCorrompu[] = $fichier;
						unlink(CHEMIN_FLUX . $fichier);
						$GLOBALS['msg'] .= $GLOBALS["langue"]->get("FICHIER_NON_CHARGER", $fichier) . "<br>";
					}
				}
			}
				
			//on va construire un tableau contenant les id libres pour les items
			arsort($GLOBALS["arrayIdItem"]);
				
			//je ne sais pas si c'est la bonne solution, mais array_shift est la seul méthode que j'ai trouver pour récupérer le 1er élément
			//$tab[0] ne marche pas car j'ai des clés non numérique (pourtant je pensais que ça marchait quand même)
			//Du coup, comme je dépile le 1er élément, il e faut pas que je le passe dans la boucle car il sera considé comme libre alors qu'il ne l'est forcement pas.
			$max = array_shift($GLOBALS["arrayIdItem"]);
				
			for ($cpt = 1; $cpt < $max; $cpt++)
			{
				if(!isset($GLOBALS["arrayIdItem"]["id$cpt"]))
				{
					$GLOBALS["arrayIdItemLibre"]["id$cpt"] = $cpt;
				}
			}
				
			//on ajoute le 1er id supérieur au max qui sera lui toujours libre
			$max++;
			$GLOBALS["arrayIdItemLibre"]["id$max"] = $max;
				
		}
		//si on en a pas, cela signifie que répertoire vient d'être créé. On va donc créer le fichier .htaccess qui interdit l'acces aux fichiers flux
		else
		{
			verifHtaccess(CHEMIN_FLUX);
		}

		//on va trier les flux par position
		foreach($listeCat as &$listeFlux)
		{
			usort($listeFlux, "triFluxParPosition");
		}
		$GLOBALS["listeFluxRss"] = $listeCat;
	
		
		$fichierSave = REPERTOIRE_SAUVEGARDE . "save.opml";
		if(count($listeCorrompu) > 0 && file_exists($fichierSave))
		{
			if(import($fichierSave, false))
			{
				$GLOBALS['msg'] .= $GLOBALS["langue"]->get("MSG_FICHIER_CORROMPU_OK");
			}
			else
			{
				$GLOBALS['msg'] .= $GLOBALS["langue"]->get("MSG_FICHIER_CORROMPU_KO");
			}
		}
	}

	return $GLOBALS["listeFluxRss"];
}


/**
 * fonction qui retourne le premier id non utilisé pour la table $table.
 *  Lorsque l'on utilise cette fonction, l'id est automatiquement marqué comme utilisé.
 * @param $table	Array   : table dont on veut connaitre le prochain id
 * @return int
 */
function getIdSuivant(&$table)
{
	$id = 1; //id suivant potentiel. Si je le trouve dans le tableau, j'essaye le suivant
	$trouver = false;
	//j'essaie tous les id à partir de 1 et je teste s'il est dans la liste. S'il n'y est pas, ça sera la valeur de l'id suivant
	while(!$trouver && $id <= count($table))
	{
		if(!isset($table["id$id"]))
		{
			$trouver = true;
		}
		else
		{
			$id++;
		}
	}
	$table["id$id"] = $id;

	return $id;
}


/**
 * fonction qui renvoie un id d'item non utilisé
 * @return int
 */
function getIdItemSuivant()
{
	$id = 1;
	//si il y a des items non utilisés, on va prendre le 1er
	if(count($GLOBALS["arrayIdItemLibre"]) > 1)
	{
		$id = array_shift($GLOBALS["arrayIdItemLibre"]);
	}

	//s'il n'y a qu'un seul élément, cela signifie qu'il n'y a pas de "trou" dans la liste des id
	//Il ne reste dans le tableau que l'id suivant le max
	elseif(count($GLOBALS["arrayIdItemLibre"]) == 1)
	{
		$id = array_shift($GLOBALS["arrayIdItemLibre"]);
		$idSuiv = $id + 1;
		$GLOBALS["arrayIdItemLibre"]['id' . $idSuiv] = $idSuiv;
	}
	elseif(count($GLOBALS["arrayIdItemLibre"]) == 0)
	{
	}

	$GLOBALS["arrayIdItem"]['id' . $id] = $id;
	utiliseIdItem($id);
	return $id;
}


/**
 * fonction qui gère les id des items utilisés
 * @param $id
 */
function utiliseIdItem($id)
{
	$GLOBALS["arrayIdItem"]['id' . $id] = $id;

	//si l'id est dans le tableau des id libre, on le supprime de ce tableau
	if(isset($GLOBALS["arrayIdItemLibre"]['id' . $id]))
	{
		unset($GLOBALS["arrayIdItemLibre"]['id' . $id]);
	}
}


/**
 * fonction qui retourne l'url du serveur avec le bon protocol
 * @return String
 */
function getServeur()
{
	$https = (!empty($_SERVER['HTTPS']) && (strtolower($_SERVER['HTTPS'])=='on')) || $_SERVER["SERVER_PORT"]=='443'; // HTTPS detection.
	$serverport = ($_SERVER["SERVER_PORT"]=='80' || ($https && $_SERVER["SERVER_PORT"]=='443') ? '' : ':'.$_SERVER["SERVER_PORT"]);

	return "http" . ($https?"s":"") . "://" . $_SERVER['SERVER_NAME'].$serverport . $_SERVER['SCRIPT_NAME'];
}


/**
 * fonction qui crée le fichier de sauvegarde opml
 */
function creeSaveOpml()
{
	$nomFichier = "save.opml";
	$handle = @fopen(REPERTOIRE_SAUVEGARDE . $nomFichier, "w+");
	@fwrite($handle,getOpml($nomFichier));
	@fclose($handle);
}


/**
 * fonction qui défini si une catégrie contient au moins un flux non accessible
 * @param $idCat
 * @return boolean
 */
function catNonDispo($idCat)
{
	if(isset($GLOBALS["listeFluxRss"][$idCat]) && count($GLOBALS["listeFluxRss"][$idCat]) > 0)
	{
		foreach($GLOBALS["listeFluxRss"][$idCat] as $flux)
		{
			if($flux->getEtat() == RSS_NON_ACCESSIBLE)
			{
				return true;
			}
		}
	}
	return false;
}


/**
 * fonction qui remplace le caractère & par une chaine reconnaissable pour éviter les problèmes d'interpretation xml.
 * @param $text		String	: string à tester
 * @param $etape1	boolean	: sert à savoir dans quel sens on fait le hack
 * @return String $text hacké
 */
function hackXlmNonValide($text, $etape1=false)
{
	if($etape1)
	{
		return str_replace("&", CARACTERE_ET, $text);
	}
	else
	{
		return str_replace(CARACTERE_ET, "&", $text);
	}
}


/**
 *  fonction qui met à jour les positions dans les flux (utile quand je fais des tests et que je fous le bordel)
 */
function razPosition()
{
	chargerListeFlux();
	foreach($GLOBALS['listeFluxRss'] as $idCat=>$listeFlux)
	{
		$pos = 1;
		foreach($listeFlux as $flux)
		{
			$flux->setPosition($pos);
			$flux->enregistrer();
			$pos++;
		}
	}
}
?>
